#ifndef CVIEW_H
#define CVIEW_H

/* User header file */

#include "defines.h"

/* functions that result in buttons */
cvId   *cvNewView(     short task, const char label[], void *data, char **key,
                        short numtypes, short numpoints,
						long flags );
void	cvViewBounds(	cvId *id_or_ALL,	/* allow ALL, FOLLOW, PRECEDE, NEXT, PREV keywords?? */
						float xmax, float ymax, float zmax, float xmin, float ymin, float zmin );
void	cvViewScale(	cvId *id_or_ALL,
						float xscale, float yscale, float zscale );
void	cvViewDims(	cvId *id_or_ALL,
						long xlen, long ylen, long zlen );

void cvCurrentWindow( cvButtonId windowIndex );
cvButtonId cvGetButtonFromWidget( Widget w );
void cvSetXData( cvButtonId ibutton );

int cvIsAvailable( const cvId* id );
int cvYDirection( const cvId* id );
int cvXDirection( const cvId* id );
void cvShow( const cvId* id );
void cvHide( const cvId* id );
int cvIsHidden( const cvId* id );
int cvFlags( const cvId* id );
const char* cvName( const cvId* id );
float cvXScale( const cvId* id );
float cvYScale( const cvId* id );
float cvZScale( const cvId* id );
float cvHorizScale( const cvId* id );
float cvVertScale( const cvId* id );
int cvSizeInPixels( const cvId* id );
int cvSetActiveLayer( const cvId* id );
cvId* cvActiveLayer( int ibutton );
cvPoint2dData** cvFindNearestPoint( const cvId* id, float x, float y, int* n );
cvSegmentData** cvFindNearestArc( const cvId* id, float x, float y, int* n );
cvPieData** cvFindNearestPie( const cvId* id, float x, float y, int* n );
cvBarData** cvFindNearestBar( const cvId* id, float x, float y, int* n );
void cvSelectionMethod( const cvId*, SelectionMethod );
void cvSetViewType( const cvId* id, int type );
cvId* cvNextLayerFromId( const cvId* id );
cvId* cvNextLayer( int ibutton );
int cvLayerIndexOfType( const cvId* id, ViewType viewType );
void cvFreeView( const cvId* id );
void cvSetFreeLayerData( const cvId* id, FreeUserData freeUserData );
void cvFreeWindow( int windowIndex );

/*
short	cvModView(		cvId *id,		// return a `short' for error code??
						short task, char label[], void *data, char **key,
						short numtypes, short numpoints,
						long flags );
*/

/* Override the default colors. */
void cvColorList( int colorMode, int ncolors, ... );

/* Add your title to the graphics window. */
void	cvTitle(		char *titlestring );

/* This string is displayed below the key and is updated at each call of cvUpdate() below. */
void	cvCounter(		char *string );

/* Mandatory window-starter. */
#ifdef FRAMEWORK
	#include <X11/Intrinsic.h>
	Widget cvDrawWindow(
		XtAppContext appContext,
		cvButtonId* window,
		Widget appParentWidget,
		short locolor
	);
#else
	void cvDrawWindow( int *ac, char *av[], short locolor );
#endif

/* Two purposes: */
/* 1. Check for user mouse input and change the current view. */
/* 2. Update current view based on new data. */
void	cvUpdate(	void );

/* Just purpose #1 of cvUpdate above, for use in long loops. */
void	cvEventCheck(	void );

/* After all calculation is finished, optionally call this function so user has */
/* graphical access to final state of program (pseudo-)indefinitely.			*/
void	cvWait( void );

/* Allows user to pass params in a pseudo-uniform way to easyX */
/* User can then use these params to modify functions in easyX */
void	cvParams( float user1, float user2 );

/*
Blatant sortie kludge.
Each switch defaults to FALSE, sortie users must call this function
	and pass TRUE as desired.
*/
void	cvSortie( short SORTIE, short MANIFOLD );



/* Prototypes */
cvDataFmt *cvDefDataFmt( cvId *id,
						long flags, size_t type,
						size_t x, size_t y, size_t z,
						size_t next, size_t extra );
void cvUseDataFmt( cvId *id, cvDataFmt *fmt );
long cvGetData   ( cvId *id, void **data );

void cvTransform( float xmax, float ymax, float zmax, cvPoint3d *dataptr );

#endif
