#ifndef DEFINES_H
#define DEFINES_H

#include "x.h"

#include "iostream.h"

#define MAX(a,b) ( (a)>(b) ? (a) : (b) )
#define MIN(a,b) ( (a)<(b) ? (a) : (b) )
#define SQR(a)   ( (a) * (a) )
#define EMPTY       -1
#define FULL        -2
#define UNASSIGNED  -1
#define FULLARC         0, 360*64

#define LOWCOLORSIDE		3
#define MAXKEYLEN			7
#define MAXNUMTYPES			10
#define MAXTYPECOLORS		11
#define MAXCELLKEYNUM		50
#define LOG10_OF_100		2.
#define FLOATCHARLEN		9
#define ROUND_TO_ZERO		.1		/* assumes %.1f fprintf format */

#define MAXBUTTONNUMBER		30
#define MAXGRAFTYPENUMBER	30
#define MAX_OVERLAYS		30

#define SQR(a) ( (a) * (a) )
#define DIST( x0, y0, x1, y1 ) ( sqrt( (double) (SQR(((x1)-(x0))) + SQR(((y1)-(y0)))) ) )

typedef void* XtPointer;

const int cvInvalidType = -99;
const int cvInvalidLayerIndex = -99;

/*
	This struct holds the user's data format definition.
	The `next' field is mainly for linked lists;
		`next' is also used for arrays as `dim5'.
	The `extra' field is used only for arrays (as `dim6').
*/
typedef struct {
	long flags;
	size_t type;
	size_t x, y, z;
	size_t next;
	size_t extra;
} cvDataFmt;

typedef struct {
	short ibutton, iview;
} cvId;

typedef void (*SelectionMethod) ( float, float, long, long, long, long );
typedef void (*FreeUserData) ( void* userData, int nPoints );

struct paramlist {
	int graftype;
	long flags;
	long xlen, ylen, zlen;
	long numtypes, numpoints;
	float xmax, ymax, zmax;
	float xmin, ymin, zmin;
	float xscale, yscale, zscale;
	void *udata;
	char **legend;
	cvDataFmt *fmt;
	cvId id;
	SelectionMethod selectionMethod;
	FreeUserData freeUserData;
	char* name;
};

typedef BView* Widget;

struct cvColor {
	rgb_color color;

	uchar Red()   const { return color.red; }
	uchar Green() const { return color.green; }
	uchar Blue()  const { return color.blue; }

	// default ctor needed for arrays typecolors, litecolors
	cvColor()
	{
		color.red   = 0;
		color.green = 0;
		color.blue  = 0;
		color.alpha = 0;
	}

	cvColor( uchar r, uchar g, uchar b )
	{
		color.red   = r;
		color.green = g;
		color.blue  = b;
		color.alpha = 255;
	}

	cvColor( long i )
	{
		color.red   = (i >>12) & 0xff;
		color.green = (i >> 8) & 0xff;
		color.blue  = (i >> 4) & 0xff;
		color.alpha = (i     ) & 0xff;
	}

	cvColor( const rgb_color& c )
	{
		color.red   = c.red;
		color.green = c.green;
		color.blue  = c.blue;
		color.alpha = c.alpha;
	}

	cvColor( const cvColor& c )
	{
		color.red   = c.color.red;
		color.green = c.color.green;
		color.blue  = c.color.blue;
		color.alpha = c.color.alpha;
	}

	bool operator == ( const cvColor c ) const
	{
		return color.red==c.color.red && color.green == c.color.green && color.blue==c.color.blue && color.alpha==c.color.alpha;
	}

	cvColor& operator = ( const cvColor c )
	{
		if (this==&c)
			return *this;

		color.red   = c.color.red;
		color.green = c.color.green;
		color.blue  = c.color.blue;
		color.alpha = c.color.alpha;

		return *this;
	}

	operator rgb_color () { return color; }
};

const int MaxDefaultColors = 30;
extern cvColor defaultColors[ MaxDefaultColors ];

typedef struct {
	char label[10];
	short n_calls;
	struct paramlist param[MAX_OVERLAYS];
	cvId* activeLayer;
	Widget widget;
	image_data* xdata;
} cvButton;

typedef int cvButtonId;


/* The following defines are not used in x.c,
thus perhaps should be in a separate .h file */
// Should these all be prefixed "cv"?

#define NEWBUTTON		0x0000
#define OVERLAY			0x0001
#define OFFSET			0x0002

#define DrawAsLines		0x0004
#define LINES			0x0004
#define DrawAsBoxes		0x0008
#define SYMBOLS			0x0008

#define NOSCALE			0x0000
#define XSCALE			0x0010
#define YSCALE			0x0020
#define ZSCALE			0x0040

#define REDRAW			0x0000	/* should distinguish REDRAW from CLEAR: */
#define NOREDRAW		0x0080	/* first we CLEAR, then REDRAW           */
								/* eg, RASTER_MAP should never be CLEAR'd*/

#define MAX_NUM_HORIZ	0x0100
#define MAX_NUM_VERT	0x0200
#define FillSymbols		0x0200	// Repeating values is unsafe!

#define DISCRETE		0x0400
#define MINIMUM			0x0800

#define XAxisReverse	0x1000
#define YAxisReverse	0x2000

#define SizeInPixels	0x4000

#define IsHidden		0x8000

#define IsAvailable		0x10000

#define ALLOC_ALL_COLORS	0x20000


enum ViewType {
	RASTER_MAP, VECTOR_MAP,
	GRAPH_2D_INT, GRAPH_3D, GRAPH_2D_FLOAT,
	LINES_MAP, MULTILINES_MAP, LABELS_MAP,
	SYMBOL_MAP, TYPED_SYMBOL_MAP, PIES_MAP, BARS_MAP, };

#define LIST			0x01
#define ARRAY			0x02
#define ARRAY_OF_LISTS	0x04
#define GRID			0x08
#define FORMAT			0x10

#define POINTS			0
#define TYPES			1
#define AXES			2

#define OK				1
#define FAIL			2
/* #define EMPTY			3 */	/* defined above */
#define MORE			4
#define BLANK			-1

typedef float cvPoint1d;
typedef struct {
	float x, y;
} cvPoint2d;
typedef struct {
	float x, y;
	short type;
} cvPointT2d;
typedef struct {
	float x, y, z;
} cvPoint3d;
typedef struct {
	float x, y, z;
	short type;
} cvPointT3d;
typedef struct {
	short x,y;
	float z;
} cvPointG3d;	/* g is for grid */
typedef struct {
	float x0, y0, x1, y1;
	short type;
} cvSegment;

typedef struct {
	float x;
	float y;
	int pen;
} cvMultiPoint;

typedef struct {
	float x;
	float y;
	int type;
	const char* label;
} cvLabel;

typedef struct {
	float x;
	float y;
	void* data;
} cvPoint2dData;

typedef struct {
	float x;
	float y;
	void* data;
	int type;
} cvPoint2dTData;

typedef struct {
	float x0;
	float y0;
	float x1;
	float y1;
	int   type;
	void* data;
} cvSegmentData;


typedef struct {
	float value;
	void* data;
} cvSlice;

typedef struct {
	float x;
	float y;
	float z;		// radius of pie
	int nSlices;
	cvSlice* slices;
} cvPieData;

typedef struct {
	float x0;
	float y0;
	float x1;
	float y1;
	float z;			// length    of bar
	// float angle;		// direction of bar from starting point x,y
	int nSlices;
	cvSlice* slices;
} cvBarData;

