#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#include <string.h>		// strcpy

#include <Application.h>
#include <MenuField.h>
#include <PopUpMenu.h>
#include <MenuItem.h>
#include <View.h>

#include "x.h"
#include "win.h"
#include "tsb.h"

void CheckPointer( void* ptr, const char* msg );
void LockView();
void UnlockView();
void LockWindow();
void UnlockWindow();
void cvWait( void );

BApplication* app = 0;
TMainWindow* theWin = 0;
BView*   currentView = 0;

int ibutton;
// int grafkeynum;
// int cellkeynum;

int fontAscent;
int fontDescent;

/// Why can't these be const, again?

cvColor cvRed     ( 255,  0,  0 );
cvColor cvGreen   (   0,255,  0 );
cvColor cvBlue    (   0,  0,255 );
cvColor cvCyan    (   0,255,255 );
cvColor cvMagenta ( 255,  0,255 );
cvColor cvGold    ( 255,215,  0 );
cvColor cvPurple  ( 160, 32,240 );
cvColor cvBrown   ( 255, 64, 64 );
cvColor cvCoral   ( 255,114, 86 );
cvColor cvWhite   ( 255,255,255 );
cvColor cvBlack   (   0,  0,  0 );

cvColor defaultColors[] = {
	cvRed,
	cvGreen,
	cvBlue,
	cvCyan,
	cvMagenta,
	cvGold,
	cvPurple,
	cvBrown,
	cvCoral,
	cvWhite,
	cvBlack
};

cvColor backgroundColor = cvBlack;	// give user access to this in user.c

char* buttonLabel[] = { "X", "O" };
int nButtons = sizeof(buttonLabel) / sizeof( buttonLabel[0] );

main( int ac, char *av[] )
{
	set_thread_priority( find_thread(NIL), B_DISPLAY_PRIORITY );

	BApplication* app = new BApplication('MAND');
	CheckPointer( app, "main: app alloc failed" );

	// cvInitData();

	BRect rect( 90, 90, 390, 390 );

	theWin = new TMainWindow( rect, "Cview", B_TITLED_WINDOW, B_NOT_ZOOMABLE );
	CheckPointer( theWin, "main: TMainWindow alloc failed" );
	currentView = theWin->Artist();

	font_info fontInfo;
	LockView();
	currentView->GetFontInfo( &fontInfo );
	UnlockView();
	fontAscent = fontInfo.ascent;
	fontDescent = fontInfo.descent;

	const int gap = 120;
	BRect rect1( 0,0, gap,15 );
	BPopUpMenu* menu = new BPopUpMenu("Views");
	CheckPointer( menu, "main: BPopUpMenu alloc failed" );
	BMenuField* menuField1 = new BMenuField( rect1, "field3", "Views", menu );
	CheckPointer( menuField1, "main: menuField alloc failed" );

	menu->SetRadioMode(TRUE);

	theWin->AddChild( menuField1 );

	for (Index iButton=0; iButton < nButtons; iButton++) {

		BMenuItem* item = new BMenuItem( buttonLabel[ iButton ], new BMessage( iButton ));
		CheckPointer( item, "main: menuItem allocation failed" );
		menu->AddItem( item );
		if (iButton==0)
			item->SetMarked(TRUE);
	}

	/// Initial view is first menu item.
	ibutton = 0;

	theWin->Dispatch( ibutton );

	theWin->Show();

	cvWait();
}

/// Move this to a utility collection.

void CheckPointer( void* ptr, const char* msg )
{
	if (!ptr) {
		if (msg)
			printf( "%s\n", msg );
		else
			printf( "Pointer is zero\n" );
		exit(1);
	}
}

void LockView()
{
	theWin->LockView();
}

void UnlockView()
{
	theWin->UnlockView();
}

void LockWindow()
{
	theWin->Lock();
}

void UnlockWindow()
{
	theWin->Unlock();
}

/**********************************************************
	Xlib functions
**********************************************************/

void cvWait( void )
{
	// app is zero here--why??
	// app->Run();
	be_app->Run();

	// delete app;
	delete be_app;
}

/*
void cvInitData()
{
	bool allocGraphColors = true;
	bool allocCellColors  = true;

	grafkeynum = 10;
	cellkeynum = 10;

	screen_info screenInfo;
	get_screen_info( &screenInfo );

	if (screenInfo.mode == B_COLOR_8_BIT) {
		if (allocGraphColors) {
			for (int i=0; i<grafkeynum; i++) {
				Index closestIndex = index_for_color( defaultColors[i] );
				typecolors[i] = system_colors()->color_list[ closestIndex ];
				// printf("typecolors[%d]=%ld\n", i,typecolors[i]);	// debug
				// printf( "%d color %s in register %d\n", i, colorname[i], typecolors[i] );
			}
		}

		if (allocCellColors) {
			// start at one because we know we have black.
			// end at cellkeynum-1 because we know we have white.
			// uchar step = 100. / (cellkeynum-1);
			// printf( "step=%d\n", step );	// debug
			uchar step = (float) 255 / (cellkeynum-1) + .5;
			for (uchar i=0; i<cellkeynum; i++) {
				// cellkeynum should be a factor of 100
				uchar bright= i * step;		/// Should check for range error.
				cvColor gray( bright, bright, bright );
				Index closestIndex = index_for_color( gray );
				litecolors[i] = system_colors()->color_list[ closestIndex ];
				// printf("litecolors[%d]=%d\n", i,litecolors[i].Red());	// debug
			}
		}
	} else
	if (screenInfo.mode == B_RGB_32_BIT) {
		if (allocGraphColors) {
			for (int i=0; i<grafkeynum; i++) {
				typecolors[i] = defaultColors[i];
				// printf( "%d color %s in register %d\n", i, colorname[i], typecolors[i] );
			}
		}

		if (allocCellColors) {
			// start at one because we know we have black.
			// end at cellkeynum-1 because we know we have white.
			uchar step = 100. / cellkeynum;
			for (uchar i=1; i<cellkeynum; i++) {
				// cellkeynum should be a factor of 100
				uchar bright= i * step;		/// Should check for range error.
				cvColor gray( bright, bright, bright );
				litecolors[i] = gray;
			}
		}
	} else {
		printf( "cvInitData: unrecognized color space\n" );
		exit(1);
	}
}
*/


void cvMouseHandler( cvMouseButton mouseButton, int x, int y, int cols, int rows )
{
	if (mouseButton == cvMouseButton1) {
		printf("X: %d, Y: %d\n", x, y);
	} else
	if (mouseButton == cvMouseButton2) {
	} else
	if (mouseButton == cvMouseButton3) {
	}
}

