#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <string.h>

#include "cview.h"

#include <Application.h>
#include <Rect.h>
#include "win.h"


cvMultiPoint* ReadMapBounds( int& nMultiPoints );


void DoGraphics( BApplication* app, TMainWindow* win )
{
	int i, t;

	// Running on device that offers few colors?
	// If so, Cview can try to demand as few colors as possible.
	short lowcolor=TRUE;

	// Title
	char titlestring[] = "My_Title";

	// Raster-based map
		// gridlen = number of cells in each dimension of the raster-based grid (must be square).
		// gridmax = the maximum value of any cell in the raster-based grid,
			// used to scale the map from 0=black to gridmax=white.
		// gridvalues = number of gray shades you want to represent the range from 0 to gridmax.
		// grid must be a 2D array of floats, allocated as shown below.

	short gridlen=10;
	float gridmax=8.;
	short gridvalues=4;
	float **grid;

	// Vector-based map
		// vec_num = number of points in the vector-based map
		// vec_xmax, vec_ymax = max values of x, y (or 0. for auto-scaling).
		// vector must be a list of foursomes: vector[i][ 0-3 ] = x, y, color, diameter

	short vec_num=100;
	float vec_xmax=10., vec_ymax=10.;
	float **circles;
	cvSegment *lines;

	// 2D graphs

	cvPointT2d *graf0;
	float **graf1;
	int tmax2d=100;
	// float ymax2d=0.;
	float ymax2d=29.;

	float **graf0a, **graf0b;
	short fittypes=2;
	float fitmax=0.;

	// 2D graph with real x (not discrete)
	short numpoints=3;
	float ***graf2dfloat;
	float xmax2df=0.;
	float ymax2df=0.;

	// Label map

	const int MaxStringLength = 30;
	char strings[][ MaxStringLength ] = {
		"labels",
		"labels",
		"anywhere",
		"you",
		"want",
	};
	int numLabels = sizeof(strings) / sizeof(strings[0]);
	cvLabel* labels = (cvLabel*) malloc( numLabels * sizeof(cvLabel) );

	// multi-line map

	int nMultiPoints;
	cvMultiPoint* mapPoints = ReadMapBounds( nMultiPoints );

	// US bounds

	struct {
		float xmin;
		float xmax;
		float ymin;
		float ymax;
	} us;

	us.xmin = 40;
	us.xmax = 70;
	us.ymin = 20;
	us.ymax = 50;

	short displayGraphics;

	// Key 
		// Change the names to whatever you like.  Variables "numtypes"
		// and "stringlength" are used in dynamic allocation
		// of "legend" below.  Remember to allow one extra spot in
		// stringlength for the null terminator of each string.

		// NOTE: although I use this same legend for all the buttons
		// below, in fact each button can have its own legend.

	int numtypes=9, stringlength=7;
	char **legend;
	char typestring[10][7] = {	"aCview", "bCview", "cCview",	
								"dCview", "eCview", "fCview",
								"gCview", "hCview", "iCview",
								"jCview",
							};
	char status[10];

	int nSymbols = 40;
	int nSymbolTypes = 9;
	cvPoint2dData*  symbols = (cvPoint2dData*) malloc( nSymbols * sizeof(cvPoint2dData) );
	cvPoint2dTData* typedSymbols = (cvPoint2dTData*) malloc( nSymbols * sizeof(cvPoint2dTData) );

	int nPies = 10;
	int nBars = 10;
	cvPieData* pies = (cvPieData*) malloc( nPies * sizeof(cvPieData) );
	cvBarData* bars = (cvBarData*) malloc( nBars * sizeof(cvBarData) );
	int maxPieRadius = 25;
	int maxPieSlices = 8;
	int maxBarSlices = 8;
	int maxBarLength = 25;
	int maxSliceValue = 10;

	int nViews;

	// Process command line arguments here.
	// Ideally, you should give the user:
	//		1. a usage statement, and
	//		2. an option to avoid graphics
	// See the sample code that does this at the end of this file.

	// if (ac > 1) tmax2d = atoi( av[1] );

	// Seed random number generator
	srand(0);

	// Change to FALSE to suppress graphics (eg, based on user input)
	displayGraphics = TRUE;


	// 2D graph
	graf1 = (float **)	calloc(tmax2d+1, sizeof(float *));
	for (i=0; i<tmax2d+1; i++)
		graf1[i]=(float *) calloc(numtypes, sizeof(float));
	
	// 2D graph with real x
	graf2dfloat = (float ***)	calloc(numtypes, sizeof(float **));
	for (i=0; i<numtypes; i++) {
		short j;
		graf2dfloat[i]=(float **) calloc(numpoints, sizeof(float *));
		for (j=0; j<numpoints; j++)
			graf2dfloat[i][j]=(float *) calloc(2, sizeof(float));
	}
	
	// Raster map
	grid = (float **)	calloc(gridlen, sizeof(float *));
	for (i=0; i<gridlen; i++)
		grid[i]=(float *) calloc(gridlen, sizeof(float));

	// Vector map
	circles = (float **)	calloc(vec_num, sizeof(float *));
	for (i=0; i<vec_num; i++)
		circles[i]=(float *) calloc(4, sizeof(float));
	// Note that lines must be an array of cvSegment structures.
	lines = (cvSegment *) calloc(vec_num, sizeof(cvSegment));
	
	// For the next two arrays, numtypes=1,
	// used for "data fit" button
	graf0a = (float **)	calloc(tmax2d+1, sizeof(float *));
	for (i=0; i<tmax2d+1; i++)
		graf0a[i]=(float *) calloc(fittypes, sizeof(float));
	
	graf0b = (float **)	calloc(tmax2d+1, sizeof(float *));
	for (i=0; i<tmax2d+1; i++)
		graf0b[i]=(float *) calloc(fittypes, sizeof(float));
	
	// Key
	// Using 1+numtypes rather than numtypes to demonstrate the use of
	// the extra color, black.
	legend = (char **) calloc(1+numtypes, sizeof(char *));
	for (i=0; i<1+numtypes; i++) {
		legend[i] = (char *)	malloc(stringlength);
		strcpy( legend[i], typestring[i] );
	}

	// Initialize graphics
	if (displayGraphics) {
		// These variables exists merely to assist the programmer in
		// remembering the order of the arguments in the cvNewView() function.
		void *cv_data;
		char **cv_key;
		short cv_numtypes, cv_numpoints;
		short cv_xlen, cv_ylen, cv_zlen;
		float cv_xmax, cv_ymax, cv_zmax;
		float cv_xmin, cv_ymin, cv_zmin;
		float pHorizData;
		float pVertData;
		float pLegendWidth;

		cvId* view[30];
		int   iView = 0;

		// The 2D graph is a line graph with up to 9 lines.

		view[iView] =
		cvNewView( GRAPH_2D_INT, "G2D", cv_data=graf1, cv_key=legend,
					cv_numtypes=numtypes, cv_numpoints=tmax2d,
					NEWBUTTON | YSCALE );
		cvViewBounds(  view[iView],
						cv_xmax=0., cv_ymax=ymax2d, cv_zmax=0.,
						cv_xmin=0., cv_ymin=0.    , cv_zmin=0. );
		cvViewDims(	view[iView],
						cv_xlen=0, cv_ylen=0, cv_zlen=0 );
		// The following format statement is not needed because the data are
		// in the standard Cview format for GRAPH_2D_INT, not the old format.
		// cvDefDataFmt( view[iView], ARRAY, POINTS, TYPES, BLANK, BLANK, BLANK, BLANK);
		iView++;

		// Labels map

		view[iView] =
		cvNewView( LABELS_MAP, "labels", cv_data=labels, cv_key=0,
					cv_numtypes=1, cv_numpoints=numLabels,
					NEWBUTTON | XAxisReverse );
		cvViewBounds(  view[iView], cv_xmax=us.xmax, cv_ymax=us.ymax, cv_zmax=0., cv_xmin=us.xmin, cv_ymin=us.ymin, cv_zmin=0. );
		cvSetMargins( view[iView], pHorizData = .8, pVertData=.8, pLegendWidth=0. );
		iView++;

		// Symbols map

		view[iView] =
		cvNewView( SYMBOL_MAP, "symbols", cv_data=symbols, cv_key=0,
					cv_numtypes=1, cv_numpoints=nSymbols,
					NEWBUTTON );
		// Dimensions of symbol, for now confined to be a rectangle, interpreted as pixels.
		cvViewDims(	view[iView], cv_xlen=3, cv_ylen=5, cv_zlen=0 );
		iView++;

		// Typed symbols map

		view[iView] =
		cvNewView( TYPED_SYMBOL_MAP, "typSyms", cv_data=typedSymbols, cv_key=0,
					cv_numtypes=nSymbolTypes, cv_numpoints=nSymbols,
					NEWBUTTON );
		// Dimensions of symbol, for now confined to be a rectangle, interpreted as pixels.
		cvViewDims(	view[iView], cv_xlen=3, cv_ylen=5, cv_zlen=0 );
		iView++;

		// Bar map

		view[iView] =
		cvNewView( BARS_MAP, "bars", cv_data=bars, cv_key=0,
					cv_numtypes=1, cv_numpoints=nBars,
					NEWBUTTON | SizeInPixels );
		// For bars, first argument scales bar length, second arg scales bar width.
		cvViewScale( view[iView], 4.,2.,1. );
		iView++;

		// Pie map

		view[iView] =
		cvNewView( PIES_MAP, "pies", cv_data=pies, cv_key=0,
					cv_numtypes=1, cv_numpoints=nPies,
					NEWBUTTON | SizeInPixels );
		// For pies, first argument scales radius.
		cvViewScale( view[iView], 4.,1.,1. );
		iView++;

		// Pie and bar overlay

		view[iView] =
		cvNewView( PIES_MAP, "pies&bars", cv_data=pies, cv_key=0,
					cv_numtypes=1, cv_numpoints=nPies,
					NEWBUTTON | SizeInPixels );
		cvViewScale( view[iView], 4.,1.,1. );
		iView++;

		view[iView] =
		cvNewView( BARS_MAP, "bars", cv_data=bars, cv_key=0,
					cv_numtypes=1, cv_numpoints=nBars,
					OVERLAY | SizeInPixels );
		cvViewScale( view[iView], 4.,2.,1. );
		iView++;

		// 2D graph with floating point x coordinate
		// (note the `f' in the function name).

		view[iView] =
		cvNewView( GRAPH_2D_FLOAT, "G2Dfl", cv_data=graf2dfloat, cv_key=legend,
					cv_numtypes=numtypes, cv_numpoints=numpoints,
					NEWBUTTON | LINES | SYMBOLS | XSCALE | YSCALE );
		cvViewBounds(  view[iView],
						cv_xmax=xmax2df, cv_ymax=ymax2df, cv_zmax=0.,
						cv_xmin=0.     , cv_ymin=0.     , cv_zmin=0. );
		cvViewDims(	view[iView],
						cv_xlen=0, cv_ylen=0, cv_zlen=0 );
		cvDefDataFmt( view[iView], ARRAY, TYPES, POINTS, AXES, 0, 1, BLANK );
		iView++;

		// This button overlays some data points and a line

		view[iView] =
		cvNewView( GRAPH_2D_INT, "fit", cv_data=graf0a, cv_key=legend,
					cv_numtypes=fittypes, cv_numpoints=tmax2d,
					NEWBUTTON | LINES | YSCALE );
		cvViewBounds(  view[iView],
						cv_xmax=0., cv_ymax=fitmax, cv_zmax=0.,
						cv_xmin=0., cv_ymin=0.    , cv_zmin=0. );
		cvViewDims(	view[iView],
						cv_xlen=0, cv_ylen=0, cv_zlen=0 );
		cvDefDataFmt( view[iView], ARRAY, POINTS, TYPES, BLANK, BLANK, BLANK, BLANK);
		iView++;

		view[iView] =
		cvNewView( GRAPH_2D_INT, "", cv_data=graf0b, cv_key=0,
					cv_numtypes=fittypes, cv_numpoints=tmax2d,
					OVERLAY | SYMBOLS | YSCALE );
		cvViewBounds(  view[iView],
						cv_xmax=0., cv_ymax=fitmax, cv_zmax=0.,
						cv_xmin=0., cv_ymin=0.    , cv_zmin=0. );
		cvViewDims(	view[iView],
						cv_xlen=0, cv_ylen=0, cv_zlen=0 );
		cvDefDataFmt( view[iView], ARRAY, POINTS, TYPES, BLANK, BLANK, BLANK, BLANK);
		iView++;

		// A raster-based grid of gray-shade squares.
		// [After fun. separation: Default size is cv_numpoints units square.]

		view[iView] =
		cvNewView( RASTER_MAP, "MapCell", cv_data=grid, cv_key=NULL,
					cv_numtypes=gridvalues, cv_numpoints=0,
					NEWBUTTON );
		cvViewBounds(  view[iView],
						cv_xmax=0., cv_ymax=0., cv_zmax=gridmax,
						cv_xmin=0., cv_ymin=0., cv_zmin=0. );

		// This cvViewDims() call could be avoided by passing cv_numpoints=gridlen
		// in the cvNewView() call above, as illustrated in the raster layer
		// of the raster/vector overlay ("MapOvl") example below.

		cvViewDims(	view[iView], cv_xlen=gridlen, cv_ylen=gridlen, cv_zlen=0 );

		cvDefDataFmt( view[iView], GRID, BLANK, BLANK, BLANK, BLANK, BLANK, BLANK);
		iView++;

			// "map_vector" is a vector-based map of up to 9 types (colors)
			// of circles (by default) of user-specified position and diameter.
			// NOTE: new argument "zmax" (here it's zero) after ymax.
			// NOTE: Black is the 10th color (color 9);
			// NOTE: To write disjoint line segments, include LINES flag
		    //       and note the mem allocation for `lines' above.

		view[iView]=
		cvNewView( VECTOR_MAP, "MapVec", cv_data=circles, cv_key=legend,
					cv_numtypes=1+numtypes, cv_numpoints=vec_num,
					NEWBUTTON );
		cvViewBounds(  view[iView],
						cv_xmax=vec_xmax, cv_ymax=vec_ymax, cv_zmax=0.,
						cv_xmin=0.      , cv_ymin=0.      , cv_zmin=0. );
		cvViewDims(	view[iView],
						cv_xlen=0, cv_ylen=0, cv_zlen=0 );
		cvDefDataFmt( view[iView], ARRAY, POINTS, AXES, 0, 1, 2, 3);
		iView++;

		view[iView]=
		cvNewView( LINES_MAP, "MapLin", cv_data=lines, cv_key=legend,
					cv_numtypes=numtypes, cv_numpoints=vec_num,
					NEWBUTTON | LINES );
		cvViewBounds(  view[iView],
						cv_xmax=vec_xmax, cv_ymax=vec_ymax, cv_zmax=0.,
						cv_xmin=0.      , cv_ymin=0.      , cv_zmin=0. );
		iView++;


		// Here's a US map
		// We use XAxisReverse because longitude is presented as degrees West.
		// Under X11, all lines are drawn, but some are missing here--
		// I'll figure this out later.

		{
			int gray   = 0;
			char** legend = 0;
			// cvNewView( MULTILINES_MAP, BordersName.chars(), mapPoints, legend,
			cvNewView( MULTILINES_MAP, "US", mapPoints, legend,
				gray, nMultiPoints,
				NEWBUTTON | LINES | XSCALE | YSCALE | XAxisReverse );
		}

			// This call just demonstrates that you can have more than one
			// graph of each type.	 In fact, you can have up to 30 buttons,
			// in any combination of graphs and maps.		

		view[iView] =
		cvNewView( GRAPH_2D_INT, "G2D_2", cv_data=graf1, cv_key=legend,
					cv_numtypes=numtypes, cv_numpoints=tmax2d,
					NEWBUTTON );
		cvViewBounds(  view[iView],
						cv_xmax=0., cv_ymax=39., cv_zmax=0.,
						cv_xmin=0., cv_ymin=0. , cv_zmin=0. );
		cvViewDims(	view[iView],
						cv_xlen=0, cv_ylen=0, cv_zlen=0 );
		cvDefDataFmt( view[iView], ARRAY, POINTS, TYPES, BLANK, BLANK, BLANK, BLANK);
		iView++;

		cvDrawWindow( app, win );
	}

	nViews = cvNumViews();
	printf("Cycling through %d views...\n", nViews);

	// Do iterative calculations in this loop
	for (t = 0; t < tmax2d ; t++) {

		int i;

		// printf("t=%d\n",t);

		int viewIndex = nViews * ((float)t/tmax2d);
		cvDisplayView( viewIndex );

		// example calculations follow 
		// See "IMPORTANT" note in comment below. 

		// Update the status string (which is monitored by Cview due to
		// the above cvCounter() call). 

		sprintf( status, "%d", t );

		// A "time-series" graph is provided. 
		// Each can contain up to numtypes lines.
		// The variable 't' needn't be time; could be iteration, whatever.

		for (i=0;i<numtypes;i++) {
			// random line and point data
			graf1[t][i]= rand() % (long) 29;
		}

		// Load the "data fit" arrays with some numbers.

		graf0a[t][0]=t;
		graf0b[t][0]=t;
		graf0a[t][1]=1.0+t;
		graf0b[t][1]=1.5+t;

		// Another "time-series" graph; this one allows x coordinates
		// to be real

		for (i=0; i<numtypes; i++) {
			short j;
			for (j=0; j<numpoints; j++) {
				// draw some lines
				float x = (float) j;
				float y = ((float)(i+1)/numtypes)*x;
				graf2dfloat[i][j][0] = x;
				graf2dfloat[i][j][1] = y;
			}
		}


		// Currently this raster-based grid supplies only gray shades
		// (so it's easy to see the cardinal ordering of values).

		for (i=0;i<gridlen;i++) {
			int j;
			for (j=0;j<gridlen;j++) {
				// random brightnesses in spatial grid2
				grid[i][j] = gridmax * (rand()%1000)/1000.;
			}
		}


		// In this vector-based map, you specify the x and y positions
			// as well as the value at that position, for each point.	   
		// The diameter of the circle drawn provides another dimension.
		// The lower-left corner of the window is the origin (0,0), and
		// the upper-right corner is at (vec_xmax, vec_ymax).		

		for (i=0;i<vec_num;i++) {
			float r=gridmax * (rand()%1000)/1000.;
			float theta=1.57 * (rand()%1000)/1000.;
			//		 [0] x coordinate				
			//		 [1] y coordinate				
			//		 [2] diameter of circle drawn	
			//		 [3] color					
			circles[i][0] = r*cos(theta);					
			circles[i][1] = r*sin(theta);					
			circles[i][2] = (vec_xmax/10.)*(rand()%1000)/1000.;		
			circles[i][3] = (2+numtypes)*(rand()%1000)/1000.;	

			lines[i].x0 = r*cos(theta);					
			lines[i].y0 = r*sin(theta);					
			lines[i].x1 = lines[i].x0 + (r/20.)*cos(theta+M_PI/2.);
			lines[i].y1 = lines[i].y0 + (r/20.)*sin(theta+M_PI/2.);
			lines[i].type = (1+numtypes)*(rand()%1000)/1000.;	
		}


		// The bar data

		for (int i=0; i<nBars; i++) {
			int nSlices = rand()%maxBarSlices;
			bars[i].x0 =  (rand()%1000)/1000.;
			bars[i].y0 =  (rand()%1000)/1000.;
			bars[i].x1 =  (rand()%1000)/1000.;
			bars[i].y1 =  (rand()%1000)/1000.;
			bars[i].z =  rand()%maxBarLength;
			bars[i].nSlices =  nSlices;
			bars[i].slices = (cvSlice*) malloc( nSlices * sizeof(cvSlice) );
			cvSlice* slices = bars[i].slices;
			for (int iSlice=0; iSlice < nSlices; iSlice++) {
				int value = rand() % maxSliceValue;
				slices[ iSlice ].value = value;
				int* sliceIndex = (int*) malloc( sizeof(int) );
				*sliceIndex = value;
				slices[ iSlice ].data = (void*) value;
			}
		}


		// The pie data

		for (int i=0; i<nPies; i++) {
			int nSlices = rand()%maxPieSlices;
			pies[i].x =  (rand()%1000)/1000.;
			pies[i].y =  (rand()%1000)/1000.;
			pies[i].z =  rand()%maxPieRadius;
			pies[i].nSlices =  nSlices;
			pies[i].slices = (cvSlice*) malloc( nSlices * sizeof(cvSlice) );
			cvSlice* slices = pies[i].slices;
			for (int iSlice=0; iSlice < nSlices; iSlice++) {
				slices[ iSlice ].value = rand() % maxSliceValue;
				int* sliceIndex = (int*) malloc( sizeof(int) );
				*sliceIndex = slices[ iSlice ].value;
				slices[ iSlice ].data = (void*) sliceIndex;
			}
		}


		// The typed symbol data

		for (int i=0; i<nSymbols; i++) {
			typedSymbols[i].x =  (rand()%1000)/1000.;
			typedSymbols[i].y =  (rand()%1000)/1000.;
			int* symbolIndex = (int*) malloc( sizeof(int) );
			*symbolIndex = i;
			typedSymbols[i].data = (void*) symbolIndex;
			typedSymbols[i].type = i % nSymbolTypes;
			// printf("symbol %d at %.1f %.1f\n", i, typedSymbols[i].x, typedSymbols[i].y);
		}


		// The symbol data

		for (int i=0; i<nSymbols; i++) {
			symbols[i].x =  (rand()%1000)/1000.;
			symbols[i].y =  (rand()%1000)/1000.;
			int* symbolIndex = (int*) malloc( sizeof(int) );
			*symbolIndex = i;
			symbols[i].data = (void*) symbolIndex;
			// printf("symbol %d at %.1f %.1f\n", i, symbols[i].x, symbols[i].y);
		}


		// The label data

		for (int i=0; i<numLabels; i++) {
			float verticalSegment = (us.ymax-us.ymin) / 5.;
			labels[i].x = us.xmin + (us.xmax-us.xmin) * (rand()%1000)/1000.;
			labels[i].y = us.ymax - i*verticalSegment - verticalSegment * (rand()%1000)/1000.;
			labels[i].type  = i;
			labels[i].label = (char*) malloc( strlen(strings[i]) + 1 );
			strcpy( labels[i].label, strings[i] );
			// printf("label %d at %.1f %.1f\n", i, labels[i].x, labels[i].y);
		}


		// The next line provides updates of the display every time step.
		// IMPORTANT: 

		// 1.	When you change the data and want the graphs/maps updated, call
			// cvUpdate();

		// 2.  FOR X11 ONLY: DOES NOT APPLY TO BeOS:
			// If each time step takes more than a few seconds to calculate,
			// consider putting a call to
			// cvEventCheck();
			// into some calculation-intensive inner-loops.
			// This will make the program respond to your mouseclicks
			// even while it's inside an iteration.

		if (displayGraphics) cvUpdate();
	}

	printf("...select views from the menu, resize the window and select points with the left mouse button.\n");
 
	/*
		The next line isn't necessary, but it keeps the display available
		after the calculation is finished, in case you ran it overnight
		and want to see the final result when you come in the next day.
	*/

	// if (displayGraphics) cvWait();
}


struct {
	int pen;
	float lon;
	float lat;
} usMap[] = {
	{ 3, 70.807, 43.125 },
	{ 2, 70.883, 43.268 },
	{ 2, 71.033, 43.381 },
	{ 2, 71.050, 43.512 },
	{ 2, 71.229, 45.344 },
	{ 3, 70.807, 43.125 },
	{ 2, 70.718, 43.194 },
	{ 2, 70.660, 43.354 },
	{ 2, 70.526, 43.371 },
	{ 2, 70.452, 43.570 },
	{ 2, 70.303, 43.627 },
	{ 2, 70.408, 43.690 },
	{ 2, 70.244, 43.787 },
	{ 2, 70.093, 43.844 },
	{ 2, 70.003, 43.912 },
	{ 2, 69.988, 43.780 },
	{ 2, 69.928, 43.769 },
	{ 2, 69.898, 43.849 },
	{ 2, 69.868, 43.929 },
	{ 2, 69.763, 43.865 },
	{ 2, 69.717, 43.985 },
	{ 2, 69.628, 43.881 },
	{ 2, 69.506, 44.029 },
	{ 2, 69.491, 44.069 },
	{ 2, 69.446, 44.017 },
	{ 2, 69.386, 44.005 },
	{ 2, 69.235, 44.061 },
	{ 2, 69.204, 44.141 },
	{ 2, 69.141, 44.300 },
	{ 2, 69.078, 44.460 },
	{ 2, 68.894, 44.595 },
	{ 2, 68.865, 44.503 },
	{ 2, 68.881, 44.463 },
	{ 2, 68.973, 44.396 },
	{ 2, 68.748, 44.307 },
	{ 2, 68.716, 44.387 },
	{ 2, 68.624, 44.454 },
	{ 2, 68.592, 44.534 },
	{ 2, 68.548, 44.482 },
	{ 2, 68.455, 44.549 },
	{ 2, 68.318, 44.564 },
	{ 2, 68.214, 44.499 },
	{ 2, 68.202, 44.367 },
	{ 2, 68.170, 44.447 },
	{ 2, 68.077, 44.514 },
	{ 2, 68.000, 44.541 },
	{ 2, 67.890, 44.648 },
	{ 2, 67.770, 44.623 },
	{ 2, 67.676, 44.690 },
	{ 2, 67.556, 44.664 },
	{ 2, 67.445, 44.771 },
	{ 2, 67.341, 44.705 },
	{ 2, 67.153, 44.838 },
	{ 2, 67.119, 44.918 },
	{ 2, 67.179, 44.931 },
	{ 2, 67.240, 44.944 },
	{ 2, 67.284, 44.996 },
	{ 2, 67.189, 45.063 },
	{ 2, 67.233, 45.116 },
	{ 2, 67.320, 45.221 },
	{ 2, 67.364, 45.274 },
	{ 2, 67.459, 45.207 },
	{ 2, 67.520, 45.220 },
	{ 2, 67.591, 45.365 },
	{ 2, 67.585, 45.538 },
	{ 2, 67.568, 45.577 },
	{ 2, 67.595, 45.670 },
	{ 2, 67.673, 45.643 },
	{ 2, 67.902, 45.734 },
	{ 2, 67.946, 45.787 },
	{ 2, 67.896, 45.907 },
	{ 2, 67.885, 46.252 },
	{ 2, 67.919, 47.132 },
	{ 2, 68.027, 47.198 },
	{ 2, 68.336, 47.435 },
	{ 2, 68.542, 47.432 },
	{ 2, 68.559, 47.392 },
	{ 2, 68.718, 47.336 },
	{ 2, 68.798, 47.308 },
	{ 2, 69.020, 47.264 },
	{ 2, 69.146, 47.289 },
	{ 2, 69.192, 47.341 },
	{ 2, 69.207, 47.475 },
	{ 2, 69.317, 47.540 },
	{ 2, 69.396, 47.512 },
	{ 2, 70.156, 46.786 },
	{ 2, 70.218, 46.451 },
	{ 2, 70.405, 46.313 },
	{ 2, 70.450, 46.019 },
	{ 2, 70.418, 45.927 },
	{ 2, 70.496, 45.898 },
	{ 2, 70.618, 45.748 },
	{ 2, 70.817, 45.570 },
	{ 2, 70.800, 45.437 },
	{ 2, 70.924, 45.460 },
	{ 2, 70.983, 45.299 },
	{ 2, 71.076, 45.402 },
	{ 2, 71.229, 45.344 },
	{ 3, 71.229, 45.344 },
	{ 2, 71.244, 45.304 },
	{ 2, 71.367, 45.326 },
	{ 2, 71.505, 45.308 },
	{ 2, 71.577, 45.106 },
	{ 2, 71.591, 45.066 },
	{ 3, 72.578, 42.768 },
	{ 2, 72.657, 42.910 },
	{ 2, 72.544, 43.059 },
	{ 2, 72.509, 43.351 },
	{ 2, 72.488, 43.602 },
	{ 2, 72.401, 43.672 },
	{ 2, 72.272, 43.862 },
	{ 2, 72.203, 44.063 },
	{ 2, 72.119, 44.305 },
	{ 2, 72.044, 44.334 },
	{ 2, 71.895, 44.393 },
	{ 2, 71.716, 44.532 },
	{ 2, 71.674, 44.653 },
	{ 2, 71.753, 44.795 },
	{ 2, 71.678, 44.825 },
	{ 2, 71.591, 45.066 },
	{ 3, 72.578, 42.768 },
	{ 2, 73.346, 42.732 },
	{ 3, 71.591, 45.066 },
	{ 2, 72.707, 45.048 },
	{ 2, 73.487, 45.050 },
	{ 3, 70.953, 42.897 },
	{ 2, 70.836, 43.045 },
	{ 2, 70.807, 43.125 },
	{ 3, 70.953, 42.897 },
	{ 2, 71.012, 42.908 },
	{ 2, 71.292, 42.833 },
	{ 2, 71.321, 42.753 },
	{ 2, 71.394, 42.724 },
	{ 2, 72.016, 42.753 },
	{ 2, 72.578, 42.768 },
	{ 3, 73.346, 42.732 },
	{ 2, 73.367, 42.862 },
	{ 2, 73.396, 43.164 },
	{ 2, 73.325, 43.576 },
	{ 2, 73.433, 43.637 },
	{ 2, 73.519, 43.567 },
	{ 2, 73.480, 43.687 },
	{ 2, 73.489, 43.859 },
	{ 2, 73.545, 44.081 },
	{ 2, 73.519, 44.161 },
	{ 2, 73.418, 44.272 },
	{ 2, 73.453, 44.363 },
	{ 2, 73.496, 44.626 },
	{ 2, 73.478, 44.878 },
	{ 2, 73.451, 44.959 },
	{ 2, 73.487, 45.050 },
	{ 3, 73.487, 45.050 },
	{ 2, 74.477, 44.997 },
	{ 2, 74.922, 45.024 },
	{ 2, 75.355, 44.877 },
	{ 2, 75.844, 44.526 },
	{ 2, 75.856, 44.486 },
	{ 2, 75.941, 44.413 },
	{ 2, 76.111, 44.269 },
	{ 2, 76.475, 44.110 },
	{ 2, 76.425, 44.061 },
	{ 2, 76.386, 43.971 },
	{ 2, 76.314, 44.003 },
	{ 2, 76.302, 44.043 },
	{ 2, 76.302, 44.043 },
	{ 2, 76.287, 43.872 },
	{ 2, 76.348, 43.881 },
	{ 2, 76.371, 43.800 },
	{ 2, 76.283, 43.661 },
	{ 2, 76.318, 43.539 },
	{ 2, 76.390, 43.507 },
	{ 2, 76.583, 43.493 },
	{ 2, 76.738, 43.389 },
	{ 2, 76.892, 43.284 },
	{ 2, 77.013, 43.302 },
	{ 2, 77.096, 43.229 },
	{ 2, 77.085, 43.270 },
	{ 2, 77.399, 43.271 },
	{ 2, 77.591, 43.255 },
	{ 2, 77.662, 43.223 },
	{ 2, 77.773, 43.280 },
	{ 2, 77.823, 43.329 },
	{ 2, 78.259, 43.345 },
	{ 2, 78.765, 43.326 },
	{ 2, 79.099, 43.242 },
	{ 2, 79.128, 43.120 },
	{ 2, 79.138, 43.079 },
	{ 2, 79.087, 43.031 },
	{ 2, 79.045, 42.942 },
	{ 2, 78.985, 42.935 },
	{ 2, 78.954, 42.805 },
	{ 2, 78.973, 42.724 },
	{ 2, 79.104, 42.698 },
	{ 2, 79.202, 42.543 },
	{ 2, 79.471, 42.451 },
	{ 2, 79.827, 42.244 },
	{ 3, 73.564, 42.050 },
	{ 2, 73.610, 42.100 },
	{ 2, 73.385, 42.611 },
	{ 2, 73.346, 42.732 },
	{ 3, 71.170, 41.576 },
	{ 2, 71.067, 41.514 },
	{ 2, 71.039, 41.594 },
	{ 2, 70.894, 41.651 },
	{ 2, 70.793, 41.759 },
	{ 2, 70.735, 41.748 },
	{ 2, 70.719, 41.617 },
	{ 2, 70.733, 41.578 },
	{ 2, 70.544, 41.583 },
	{ 2, 70.457, 41.652 },
	{ 2, 70.254, 41.697 },
	{ 2, 70.079, 41.662 },
	{ 2, 70.094, 41.622 },
	{ 2, 70.035, 41.611 },
	{ 2, 70.035, 41.781 },
	{ 2, 70.006, 41.861 },
	{ 2, 70.123, 42.054 },
	{ 2, 70.225, 42.117 },
	{ 2, 70.284, 42.129 },
	{ 2, 70.313, 42.049 },
	{ 2, 70.137, 42.015 },
	{ 2, 70.123, 41.884 },
	{ 2, 70.414, 41.771 },
	{ 2, 70.590, 41.805 },
	{ 2, 70.605, 41.936 },
	{ 2, 70.767, 42.009 },
	{ 2, 70.694, 42.038 },
	{ 2, 70.827, 42.191 },
	{ 2, 70.813, 42.231 },
	{ 2, 70.975, 42.305 },
	{ 2, 70.989, 42.265 },
	{ 2, 71.107, 42.287 },
	{ 2, 71.138, 42.378 },
	{ 2, 71.050, 42.447 },
	{ 2, 70.949, 42.555 },
	{ 2, 70.802, 42.612 },
	{ 2, 70.891, 42.715 },
	{ 2, 70.953, 42.897 },
	{ 3, 71.170, 41.576 },
	{ 2, 71.289, 41.769 },
	{ 2, 71.392, 41.831 },
	{ 2, 71.482, 41.933 },
	{ 2, 71.440, 42.052 },
	{ 2, 71.880, 42.049 },
	{ 3, 71.880, 42.049 },
	{ 2, 71.880, 42.049 },
	{ 2, 72.817, 42.047 },
	{ 2, 72.830, 42.007 },
	{ 2, 72.889, 42.018 },
	{ 2, 72.876, 42.058 },
	{ 2, 73.564, 42.050 },
	{ 3, 70.543, 41.413 },
	{ 2, 70.543, 41.413 },
	{ 2, 70.645, 41.476 },
	{ 2, 70.776, 41.458 },
	{ 2, 70.876, 41.350 },
	{ 2, 70.746, 41.368 },
	{ 2, 70.543, 41.413 },
	{ 3, 70.021, 41.310 },
	{ 2, 70.108, 41.412 },
	{ 2, 70.123, 41.373 },
	{ 2, 70.195, 41.344 },
	{ 2, 70.209, 41.305 },
	{ 2, 70.021, 41.310 },
	{ 3, 71.921, 41.378 },
	{ 2, 71.822, 41.487 },
	{ 2, 71.880, 42.049 },
	{ 3, 71.921, 41.378 },
	{ 2, 71.934, 41.338 },
	{ 2, 71.602, 41.403 },
	{ 2, 71.530, 41.432 },
	{ 2, 71.534, 41.603 },
	{ 2, 71.448, 41.671 },
	{ 2, 71.389, 41.660 },
	{ 2, 71.400, 41.450 },
	{ 2, 71.328, 41.479 },
	{ 2, 71.256, 41.508 },
	{ 2, 71.170, 41.576 },
	{ 3, 73.760, 41.028 },
	{ 2, 73.631, 41.048 },
	{ 2, 73.502, 41.068 },
	{ 2, 73.477, 41.148 },
	{ 2, 73.360, 41.128 },
	{ 2, 73.276, 41.198 },
	{ 2, 73.173, 41.137 },
	{ 2, 73.160, 41.177 },
	{ 2, 72.992, 41.317 },
	{ 2, 72.946, 41.267 },
	{ 2, 72.758, 41.276 },
	{ 2, 72.570, 41.284 },
	{ 2, 72.427, 41.343 },
	{ 2, 72.252, 41.311 },
	{ 2, 72.181, 41.341 },
	{ 2, 71.921, 41.378 },
	{ 3, 73.760, 41.028 },
	{ 2, 73.793, 41.118 },
	{ 2, 73.568, 41.248 },
	{ 2, 73.614, 41.298 },
	{ 2, 73.619, 41.679 },
	{ 2, 73.564, 42.050 },
	{ 3, 79.827, 42.244 },
	{ 2, 80.172, 42.077 },
	{ 2, 80.154, 42.158 },
	{ 2, 80.232, 42.084 },
	{ 2, 80.627, 41.963 },
	{ 3, 73.984, 40.897 },
	{ 2, 73.950, 40.808 },
	{ 2, 73.880, 40.838 },
	{ 2, 73.855, 40.918 },
	{ 2, 73.785, 40.948 },
	{ 2, 73.760, 41.028 },
	{ 3, 74.069, 40.617 },
	{ 2, 74.024, 40.567 },
	{ 2, 74.011, 40.607 },
	{ 2, 73.953, 40.598 },
	{ 2, 73.941, 40.638 },
	{ 2, 73.825, 40.618 },
	{ 2, 73.825, 40.618 },
	{ 2, 73.966, 40.558 },
	{ 2, 73.966, 40.558 },
	{ 2, 73.767, 40.608 },
	{ 2, 73.767, 40.608 },
	{ 2, 73.440, 40.678 },
	{ 2, 73.241, 40.728 },
	{ 2, 73.042, 40.777 },
	{ 2, 72.714, 40.845 },
	{ 2, 73.267, 40.648 },
	{ 2, 73.267, 40.648 },
	{ 2, 73.267, 40.648 },
	{ 2, 72.881, 40.706 },
	{ 2, 71.970, 41.048 },
	{ 2, 71.957, 41.088 },
	{ 2, 72.086, 41.069 },
	{ 2, 72.274, 41.061 },
	{ 2, 72.403, 41.043 },
	{ 2, 72.488, 40.973 },
	{ 2, 72.572, 40.904 },
	{ 2, 72.675, 40.965 },
	{ 2, 72.519, 41.064 },
	{ 2, 72.364, 41.162 },
	{ 2, 72.306, 41.152 },
	{ 2, 72.422, 41.173 },
	{ 2, 72.578, 41.074 },
	{ 2, 72.720, 41.015 },
	{ 2, 73.165, 40.967 },
	{ 2, 73.223, 40.978 },
	{ 2, 73.307, 40.908 },
	{ 2, 73.411, 40.968 },
	{ 2, 73.540, 40.948 },
	{ 2, 73.751, 40.858 },
	{ 2, 73.751, 40.858 },
	{ 2, 73.892, 40.798 },
	{ 2, 73.963, 40.767 },
	{ 2, 73.975, 40.727 },
	{ 2, 74.057, 40.657 },
	{ 2, 74.057, 40.657 },
	{ 2, 74.069, 40.617 },
	{ 3, 73.984, 40.897 },
	{ 2, 73.947, 41.018 },
	{ 2, 74.823, 41.373 },
	{ 3, 74.021, 40.777 },
	{ 2, 74.021, 40.777 },
	{ 2, 74.008, 40.817 },
	{ 2, 73.996, 40.857 },
	{ 2, 73.996, 40.857 },
	{ 2, 74.091, 40.747 },
	{ 2, 74.103, 40.707 },
	{ 2, 74.033, 40.737 },
	{ 2, 74.021, 40.777 },
	{ 3, 74.173, 40.677 },
	{ 2, 74.079, 40.787 },
	{ 2, 73.984, 40.897 },
	{ 3, 74.350, 40.496 },
	{ 2, 74.292, 40.486 },
	{ 2, 74.210, 40.557 },
	{ 2, 74.127, 40.627 },
	{ 2, 74.173, 40.677 },
	{ 3, 74.350, 40.496 },
	{ 2, 74.338, 40.536 },
	{ 2, 74.326, 40.576 },
	{ 2, 74.243, 40.646 },
	{ 2, 74.243, 40.646 },
	{ 2, 74.173, 40.677 },
	{ 2, 74.173, 40.677 },
	{ 3, 74.823, 41.373 },
	{ 2, 74.811, 41.413 },
	{ 2, 74.869, 41.422 },
	{ 2, 75.081, 41.540 },
	{ 2, 75.140, 41.760 },
	{ 2, 75.176, 41.850 },
	{ 2, 75.294, 41.868 },
	{ 2, 75.389, 41.967 },
	{ 2, 75.496, 42.026 },
	{ 2, 77.048, 42.004 },
	{ 2, 79.146, 41.993 },
	{ 2, 79.822, 41.993 },
	{ 2, 79.827, 42.244 },
	{ 3, 75.459, 39.795 },
	{ 2, 75.506, 39.845 },
	{ 2, 75.690, 39.832 },
	{ 2, 75.758, 39.801 },
	{ 2, 75.838, 39.729 },
	{ 2, 75.838, 39.729 },
	{ 3, 75.459, 39.795 },
	{ 2, 75.195, 39.879 },
	{ 2, 75.103, 39.990 },
	{ 2, 74.815, 40.153 },
	{ 2, 74.815, 40.153 },
	{ 2, 74.803, 40.193 },
	{ 2, 74.895, 40.292 },
	{ 2, 75.046, 40.400 },
	{ 2, 75.174, 40.588 },
	{ 2, 75.267, 40.687 },
	{ 2, 75.162, 40.839 },
	{ 2, 75.186, 40.968 },
	{ 2, 75.022, 41.110 },
	{ 2, 75.011, 41.150 },
	{ 2, 74.917, 41.262 },
	{ 2, 74.834, 41.332 },
	{ 2, 74.823, 41.373 },
	{ 3, 75.551, 39.684 },
	{ 2, 75.527, 39.555 },
	{ 2, 75.446, 39.416 },
	{ 2, 75.297, 39.309 },
	{ 2, 75.148, 39.201 },
	{ 2, 75.034, 39.182 },
	{ 2, 74.943, 39.083 },
	{ 2, 74.977, 38.963 },
	{ 2, 74.989, 38.923 },
	{ 2, 74.864, 38.944 },
	{ 2, 74.761, 39.095 },
	{ 2, 74.566, 39.356 },
	{ 2, 74.450, 39.547 },
	{ 2, 74.381, 39.577 },
	{ 2, 74.207, 39.758 },
	{ 2, 74.147, 39.957 },
	{ 2, 74.123, 40.037 },
	{ 2, 74.123, 40.037 },
	{ 2, 74.138, 39.788 },
	{ 2, 74.114, 39.868 },
	{ 2, 74.066, 40.028 },
	{ 2, 74.027, 40.357 },
	{ 2, 74.048, 40.487 },
	{ 2, 74.060, 40.447 },
	{ 2, 74.072, 40.407 },
	{ 2, 74.292, 40.486 },
	{ 2, 74.350, 40.496 },
	{ 3, 75.551, 39.684 },
	{ 2, 75.459, 39.795 },
	{ 2, 75.459, 39.795 },
	{ 3, 80.546, 40.622 },
	{ 2, 80.561, 41.123 },
	{ 2, 80.627, 41.963 },
	{ 3, 80.627, 41.963 },
	{ 2, 80.695, 41.929 },
	{ 2, 81.148, 41.813 },
	{ 2, 81.411, 41.717 },
	{ 2, 81.623, 41.574 },
	{ 2, 81.758, 41.505 },
	{ 2, 82.012, 41.449 },
	{ 2, 82.131, 41.462 },
	{ 2, 82.512, 41.376 },
	{ 2, 82.802, 41.446 },
	{ 2, 83.048, 41.429 },
	{ 2, 82.787, 41.528 },
	{ 2, 82.839, 41.574 },
	{ 2, 82.907, 41.540 },
	{ 2, 82.974, 41.505 },
	{ 2, 83.198, 41.609 },
	{ 2, 83.430, 41.672 },
	{ 2, 83.557, 41.643 },
	{ 2, 83.483, 41.719 },
	{ 3, 75.838, 39.729 },
	{ 2, 77.043, 39.703 },
	{ 2, 78.410, 39.729 },
	{ 2, 79.547, 39.711 },
	{ 3, 79.547, 39.711 },
	{ 2, 80.558, 39.710 },
	{ 2, 80.557, 40.001 },
	{ 2, 80.546, 40.622 },
	{ 3, 75.057, 38.474 },
	{ 2, 75.102, 38.523 },
	{ 2, 75.204, 38.582 },
	{ 2, 75.193, 38.622 },
	{ 2, 75.181, 38.662 },
	{ 2, 75.125, 38.652 },
	{ 2, 75.148, 38.782 },
	{ 2, 75.295, 38.890 },
	{ 2, 75.432, 39.037 },
	{ 2, 75.479, 39.296 },
	{ 2, 75.617, 39.444 },
	{ 2, 75.641, 39.573 },
	{ 2, 75.619, 39.653 },
	{ 2, 75.551, 39.684 },
	{ 3, 75.057, 38.474 },
	{ 2, 75.711, 38.455 },
	{ 2, 75.783, 38.842 },
	{ 2, 75.838, 39.729 },
	{ 3, 77.740, 39.303 },
	{ 2, 77.825, 39.440 },
	{ 2, 77.873, 39.488 },
	{ 2, 77.901, 39.617 },
	{ 2, 78.026, 39.593 },
	{ 2, 78.131, 39.649 },
	{ 2, 78.314, 39.632 },
	{ 2, 78.439, 39.608 },
	{ 2, 78.506, 39.575 },
	{ 2, 78.526, 39.494 },
	{ 2, 78.804, 39.573 },
	{ 2, 78.862, 39.581 },
	{ 2, 79.015, 39.435 },
	{ 2, 79.130, 39.450 },
	{ 2, 79.139, 39.409 },
	{ 2, 79.339, 39.311 },
	{ 2, 79.539, 39.212 },
	{ 2, 79.547, 39.711 },
	{ 3, 75.236, 38.043 },
	{ 2, 75.292, 38.052 },
	{ 3, 75.236, 38.043 },
	{ 2, 75.192, 38.203 },
	{ 2, 75.102, 38.314 },
	{ 2, 75.136, 38.403 },
	{ 2, 75.057, 38.474 },
	{ 3, 75.292, 38.052 },
	{ 2, 75.382, 37.941 },
	{ 2, 75.404, 37.861 },
	{ 2, 75.404, 37.861 },
	{ 2, 75.337, 37.892 },
	{ 2, 75.236, 38.043 },
	{ 3, 75.416, 38.031 },
	{ 2, 75.662, 37.987 },
	{ 2, 75.662, 37.987 },
	{ 3, 75.416, 38.031 },
	{ 2, 75.315, 38.181 },
	{ 2, 75.293, 38.262 },
	{ 2, 75.237, 38.252 },
	{ 2, 75.292, 38.052 },
	{ 3, 75.662, 37.987 },
	{ 2, 75.740, 37.916 },
	{ 2, 75.762, 37.836 },
	{ 2, 75.839, 37.765 },
	{ 2, 75.839, 37.765 },
	{ 2, 75.949, 37.573 },
	{ 2, 75.981, 37.453 },
	{ 2, 76.044, 37.213 },
	{ 2, 75.999, 37.164 },
	{ 2, 75.954, 37.115 },
	{ 2, 75.944, 37.155 },
	{ 2, 75.933, 37.195 },
	{ 2, 75.891, 37.355 },
	{ 2, 75.824, 37.386 },
	{ 2, 75.803, 37.466 },
	{ 2, 75.736, 37.497 },
	{ 2, 75.725, 37.537 },
	{ 2, 75.637, 37.649 },
	{ 2, 75.615, 37.729 },
	{ 2, 75.438, 37.951 },
	{ 2, 75.416, 38.031 },
	{ 3, 77.086, 38.374 },
	{ 2, 77.132, 38.423 },
	{ 2, 77.066, 38.455 },
	{ 2, 77.066, 38.455 },
	{ 2, 77.029, 38.366 },
	{ 2, 76.880, 38.260 },
	{ 2, 76.860, 38.340 },
	{ 2, 76.767, 38.243 },
	{ 2, 76.654, 38.226 },
	{ 2, 76.552, 38.168 },
	{ 2, 76.485, 38.200 },
	{ 2, 76.404, 38.062 },
	{ 2, 76.348, 38.054 },
	{ 2, 76.348, 38.054 },
	{ 2, 76.383, 38.142 },
	{ 2, 76.408, 38.271 },
	{ 2, 76.567, 38.338 },
	{ 2, 76.715, 38.444 },
	{ 2, 76.705, 38.484 },
	{ 2, 76.546, 38.418 },
	{ 2, 76.443, 38.360 },
	{ 2, 76.571, 38.547 },
	{ 2, 76.586, 38.716 },
	{ 2, 76.632, 38.765 },
	{ 2, 76.565, 38.796 },
	{ 2, 76.601, 38.885 },
	{ 2, 76.533, 38.917 },
	{ 2, 76.455, 38.988 },
	{ 2, 76.548, 39.086 },
	{ 2, 76.537, 39.126 },
	{ 2, 76.631, 39.224 },
	{ 2, 76.563, 39.255 },
	{ 2, 76.459, 39.198 },
	{ 2, 76.506, 39.247 },
	{ 2, 76.427, 39.318 },
	{ 2, 76.416, 39.359 },
	{ 2, 76.313, 39.301 },
	{ 2, 76.291, 39.381 },
	{ 2, 76.223, 39.413 },
	{ 2, 76.202, 39.493 },
	{ 2, 76.065, 39.555 },
	{ 2, 76.019, 39.506 },
	{ 2, 75.915, 39.449 },
	{ 2, 76.051, 39.386 },
	{ 2, 76.177, 39.364 },
	{ 2, 76.198, 39.283 },
	{ 2, 76.288, 39.172 },
	{ 2, 76.252, 39.083 },
	{ 2, 76.184, 39.114 },
	{ 2, 76.216, 38.994 },
	{ 2, 76.238, 38.913 },
	{ 2, 76.213, 38.784 },
	{ 2, 76.327, 38.802 },
	{ 2, 76.291, 38.713 },
	{ 2, 76.234, 38.704 },
	{ 2, 76.188, 38.655 },
	{ 2, 76.086, 38.597 },
	{ 2, 76.153, 38.566 },
	{ 2, 76.199, 38.615 },
	{ 2, 76.312, 38.633 },
	{ 2, 76.323, 38.592 },
	{ 2, 76.220, 38.535 },
	{ 2, 76.355, 38.472 },
	{ 2, 76.319, 38.383 },
	{ 2, 76.171, 38.277 },
	{ 2, 76.048, 38.299 },
	{ 2, 76.048, 38.299 },
	{ 2, 75.981, 38.330 },
	{ 2, 75.946, 38.241 },
	{ 2, 75.956, 38.201 },
	{ 2, 75.911, 38.152 },
	{ 2, 75.865, 38.103 },
	{ 2, 75.820, 38.054 },
	{ 2, 75.887, 38.023 },
	{ 2, 75.898, 37.983 },
	{ 2, 75.908, 37.943 },
	{ 2, 75.852, 37.934 },
	{ 2, 75.842, 37.974 },
	{ 2, 75.785, 37.965 },
	{ 2, 75.662, 37.987 },
	{ 3, 77.086, 38.374 },
	{ 2, 77.276, 38.319 },
	{ 2, 77.276, 38.319 },
	{ 2, 77.369, 38.416 },
	{ 2, 77.349, 38.496 },
	{ 2, 77.262, 38.609 },
	{ 2, 77.195, 38.640 },
	{ 2, 77.118, 38.712 },
	{ 2, 77.098, 38.793 },
	{ 3, 77.098, 38.793 },
	{ 2, 76.953, 38.897 },
	{ 2, 77.057, 38.954 },
	{ 2, 77.103, 39.002 },
	{ 2, 77.181, 38.930 },
	{ 3, 77.181, 38.930 },
	{ 2, 77.077, 38.873 },
	{ 2, 77.098, 38.793 },
	{ 3, 77.181, 38.930 },
	{ 2, 77.285, 38.987 },
	{ 2, 77.550, 39.109 },
	{ 2, 77.520, 39.230 },
	{ 2, 77.682, 39.294 },
	{ 2, 77.740, 39.303 },
	{ 3, 83.685, 36.577 },
	{ 2, 83.505, 36.641 },
	{ 2, 83.149, 36.729 },
	{ 2, 83.073, 36.845 },
	{ 2, 82.898, 36.869 },
	{ 2, 82.822, 36.984 },
	{ 2, 82.745, 37.100 },
	{ 2, 82.379, 37.227 },
	{ 2, 81.982, 37.514 },
	{ 3, 81.982, 37.514 },
	{ 2, 82.144, 37.573 },
	{ 2, 82.257, 37.585 },
	{ 2, 82.398, 37.765 },
	{ 2, 82.490, 37.899 },
	{ 2, 82.632, 38.079 },
	{ 2, 82.610, 38.200 },
	{ 2, 82.632, 38.409 },
	{ 2, 82.575, 38.403 },
	{ 3, 81.982, 37.514 },
	{ 2, 81.990, 37.473 },
	{ 2, 81.956, 37.346 },
	{ 2, 81.802, 37.246 },
	{ 2, 81.697, 37.193 },
	{ 2, 81.585, 37.180 },
	{ 2, 81.393, 37.282 },
	{ 2, 81.385, 37.323 },
	{ 2, 81.232, 37.222 },
	{ 2, 80.992, 37.277 },
	{ 2, 80.920, 37.351 },
	{ 2, 80.494, 37.465 },
	{ 2, 80.502, 37.425 },
	{ 2, 80.308, 37.525 },
	{ 2, 80.340, 37.653 },
	{ 2, 80.250, 37.808 },
	{ 2, 80.029, 38.029 },
	{ 2, 79.864, 38.257 },
	{ 2, 79.790, 38.330 },
	{ 2, 79.681, 38.565 },
	{ 2, 79.536, 38.423 },
	{ 2, 79.366, 38.400 },
	{ 2, 79.216, 38.547 },
	{ 2, 79.114, 38.741 },
	{ 2, 79.038, 38.814 },
	{ 2, 78.933, 38.759 },
	{ 2, 78.782, 38.905 },
	{ 2, 78.725, 38.897 },
	{ 2, 78.630, 39.051 },
	{ 2, 78.487, 39.156 },
	{ 2, 78.477, 39.197 },
	{ 2, 78.429, 39.398 },
	{ 2, 78.362, 39.431 },
	{ 2, 77.894, 39.158 },
	{ 2, 77.827, 39.190 },
	{ 2, 77.740, 39.303 },
	{ 3, 75.871, 36.559 },
	{ 2, 75.894, 36.688 },
	{ 2, 76.007, 36.915 },
	{ 2, 76.129, 36.892 },
	{ 2, 76.284, 36.959 },
	{ 2, 76.340, 36.968 },
	{ 2, 76.340, 36.968 },
	{ 2, 76.361, 36.887 },
	{ 2, 76.527, 36.913 },
	{ 2, 76.517, 36.954 },
	{ 2, 76.617, 37.011 },
	{ 2, 76.663, 37.060 },
	{ 2, 76.698, 37.148 },
	{ 2, 76.753, 37.157 },
	{ 2, 76.809, 37.166 },
	{ 2, 76.855, 37.214 },
	{ 2, 76.921, 37.183 },
	{ 2, 76.966, 37.231 },
	{ 2, 77.022, 37.240 },
	{ 2, 76.956, 37.271 },
	{ 2, 76.900, 37.263 },
	{ 2, 76.890, 37.303 },
	{ 2, 76.890, 37.303 },
	{ 2, 76.845, 37.254 },
	{ 2, 76.677, 37.229 },
	{ 2, 76.632, 37.180 },
	{ 2, 76.597, 37.091 },
	{ 2, 76.451, 36.985 },
	{ 2, 76.385, 37.016 },
	{ 2, 76.329, 37.008 },
	{ 2, 76.253, 37.079 },
	{ 2, 76.309, 37.088 },
	{ 2, 76.364, 37.097 },
	{ 2, 76.354, 37.137 },
	{ 2, 76.343, 37.177 },
	{ 2, 76.455, 37.194 },
	{ 2, 76.510, 37.203 },
	{ 2, 76.611, 37.260 },
	{ 2, 76.794, 37.455 },
	{ 2, 76.839, 37.504 },
	{ 2, 76.829, 37.544 },
	{ 2, 76.591, 37.340 },
	{ 2, 76.500, 37.243 },
	{ 2, 76.434, 37.274 },
	{ 2, 76.378, 37.266 },
	{ 2, 76.424, 37.314 },
	{ 2, 76.490, 37.283 },
	{ 2, 76.459, 37.403 },
	{ 2, 76.347, 37.386 },
	{ 2, 76.302, 37.337 },
	{ 2, 76.302, 37.337 },
	{ 2, 76.302, 37.337 },
	{ 2, 76.270, 37.457 },
	{ 2, 76.427, 37.524 },
	{ 2, 76.494, 37.492 },
	{ 2, 76.483, 37.532 },
	{ 2, 76.427, 37.524 },
	{ 2, 76.372, 37.515 },
	{ 2, 76.361, 37.555 },
	{ 2, 76.361, 37.555 },
	{ 2, 76.417, 37.564 },
	{ 2, 76.519, 37.621 },
	{ 2, 76.585, 37.590 },
	{ 2, 76.575, 37.630 },
	{ 2, 76.610, 37.719 },
	{ 2, 76.758, 37.825 },
	{ 2, 76.906, 37.930 },
	{ 2, 76.998, 38.028 },
	{ 2, 76.942, 38.019 },
	{ 2, 76.895, 37.971 },
	{ 2, 76.758, 37.825 },
	{ 2, 76.554, 37.710 },
	{ 2, 76.508, 37.661 },
	{ 2, 76.396, 37.644 },
	{ 2, 76.340, 37.635 },
	{ 2, 76.340, 37.635 },
	{ 2, 76.365, 37.764 },
	{ 2, 76.344, 37.844 },
	{ 2, 76.344, 37.844 },
	{ 2, 76.288, 37.836 },
	{ 2, 76.277, 37.876 },
	{ 2, 76.267, 37.916 },
	{ 2, 76.379, 37.933 },
	{ 2, 76.594, 38.008 },
	{ 2, 76.675, 38.146 },
	{ 2, 76.844, 38.171 },
	{ 2, 77.003, 38.237 },
	{ 2, 77.040, 38.326 },
	{ 2, 77.086, 38.374 },
	{ 3, 75.871, 36.559 },
	{ 2, 75.926, 36.568 },
	{ 3, 75.926, 36.568 },
	{ 2, 75.801, 36.172 },
	{ 2, 75.679, 35.985 },
	{ 2, 75.557, 35.797 },
	{ 2, 75.580, 35.926 },
	{ 2, 75.735, 36.203 },
	{ 2, 75.871, 36.559 },
	{ 3, 75.926, 36.568 },
	{ 2, 76.036, 36.585 },
	{ 3, 76.036, 36.585 },
	{ 2, 75.991, 36.537 },
	{ 2, 75.926, 36.568 },
	{ 3, 76.047, 36.545 },
	{ 2, 76.564, 36.544 },
	{ 2, 78.059, 36.519 },
	{ 2, 79.250, 36.560 },
	{ 2, 80.625, 36.529 },
	{ 2, 81.642, 36.567 },
	{ 3, 81.642, 36.567 },
	{ 2, 81.690, 36.614 },
	{ 2, 81.921, 36.598 },
	{ 2, 82.611, 36.550 },
	{ 2, 83.685, 36.577 },
	{ 3, 75.926, 36.568 },
	{ 2, 75.960, 36.657 },
	{ 2, 75.926, 36.568 },
	{ 3, 76.047, 36.545 },
	{ 2, 76.036, 36.585 },
	{ 3, 82.575, 38.403 },
	{ 2, 82.339, 38.420 },
	{ 2, 82.252, 38.576 },
	{ 2, 82.272, 38.785 },
	{ 2, 82.208, 38.819 },
	{ 2, 82.128, 38.935 },
	{ 2, 82.055, 39.009 },
	{ 2, 81.948, 38.956 },
	{ 2, 81.905, 38.869 },
	{ 2, 81.840, 38.903 },
	{ 2, 81.875, 39.031 },
	{ 2, 81.721, 39.221 },
	{ 2, 81.517, 39.364 },
	{ 2, 81.277, 39.379 },
	{ 2, 80.939, 39.589 },
	{ 2, 80.898, 39.791 },
	{ 2, 80.807, 39.947 },
	{ 2, 80.690, 40.224 },
	{ 2, 80.656, 40.386 },
	{ 2, 80.740, 40.562 },
	{ 2, 80.672, 40.595 },
	{ 2, 80.546, 40.622 },
	{ 3, 83.104, 34.952 },
	{ 2, 83.603, 34.962 },
	{ 2, 84.326, 34.950 },
	{ 3, 84.326, 34.950 },
	{ 2, 84.290, 35.193 },
	{ 2, 84.230, 35.229 },
	{ 2, 84.175, 35.224 },
	{ 2, 84.053, 35.294 },
	{ 2, 83.912, 35.487 },
	{ 2, 83.623, 35.541 },
	{ 2, 83.384, 35.640 },
	{ 2, 83.260, 35.710 },
	{ 2, 82.971, 35.763 },
	{ 2, 82.888, 35.919 },
	{ 2, 82.764, 35.989 },
	{ 2, 82.639, 36.058 },
	{ 2, 82.605, 35.930 },
	{ 2, 82.418, 36.034 },
	{ 2, 82.293, 36.103 },
	{ 2, 82.071, 36.078 },
	{ 2, 81.861, 36.303 },
	{ 2, 81.735, 36.371 },
	{ 2, 81.705, 36.533 },
	{ 2, 81.642, 36.567 },
	{ 3, 78.543, 33.888 },
	{ 2, 78.427, 33.913 },
	{ 2, 78.258, 33.930 },
	{ 2, 78.035, 33.938 },
	{ 2, 77.945, 34.091 },
	{ 2, 77.919, 33.962 },
	{ 2, 77.810, 34.196 },
	{ 2, 77.529, 34.444 },
	{ 2, 77.330, 34.580 },
	{ 2, 77.374, 34.629 },
	{ 2, 77.454, 34.766 },
	{ 2, 77.355, 34.709 },
	{ 2, 77.330, 34.580 },
	{ 2, 77.203, 34.644 },
	{ 2, 77.130, 34.716 },
	{ 2, 77.110, 34.796 },
	{ 2, 77.022, 34.699 },
	{ 2, 76.894, 34.762 },
	{ 2, 76.723, 34.777 },
	{ 2, 76.615, 34.760 },
	{ 2, 76.561, 34.751 },
	{ 2, 76.433, 34.814 },
	{ 2, 76.349, 34.926 },
	{ 2, 76.275, 34.997 },
	{ 2, 76.393, 34.974 },
	{ 2, 76.447, 34.983 },
	{ 2, 76.427, 35.063 },
	{ 2, 76.501, 34.992 },
	{ 2, 76.511, 34.952 },
	{ 2, 76.673, 34.978 },
	{ 2, 76.673, 34.978 },
	{ 2, 76.791, 34.955 },
	{ 2, 76.944, 35.020 },
	{ 2, 77.077, 35.166 },
	{ 2, 76.924, 35.100 },
	{ 2, 76.781, 34.995 },
	{ 2, 76.653, 35.058 },
	{ 2, 76.515, 35.161 },
	{ 2, 76.613, 35.218 },
	{ 2, 76.549, 35.250 },
	{ 2, 76.475, 35.321 },
	{ 2, 76.648, 35.307 },
	{ 2, 76.746, 35.364 },
	{ 2, 76.791, 35.413 },
	{ 2, 76.900, 35.430 },
	{ 2, 76.999, 35.487 },
	{ 2, 76.835, 35.461 },
	{ 2, 76.781, 35.453 },
	{ 2, 76.618, 35.427 },
	{ 2, 76.696, 35.565 },
	{ 2, 76.533, 35.539 },
	{ 2, 76.478, 35.530 },
	{ 2, 76.444, 35.441 },
	{ 2, 76.400, 35.393 },
	{ 2, 76.291, 35.375 },
	{ 2, 76.118, 35.389 },
	{ 2, 76.043, 35.460 },
	{ 2, 75.968, 35.531 },
	{ 2, 75.839, 35.593 },
	{ 2, 75.753, 35.704 },
	{ 2, 75.732, 35.785 },
	{ 2, 75.755, 35.914 },
	{ 2, 75.853, 35.972 },
	{ 2, 75.919, 35.940 },
	{ 2, 75.971, 35.740 },
	{ 2, 76.100, 35.678 },
	{ 2, 76.080, 35.758 },
	{ 2, 76.069, 35.798 },
	{ 2, 76.038, 35.918 },
	{ 2, 76.137, 35.976 },
	{ 2, 76.377, 35.931 },
	{ 2, 76.476, 35.988 },
	{ 2, 76.715, 35.943 },
	{ 2, 76.750, 36.031 },
	{ 2, 76.775, 36.160 },
	{ 2, 76.755, 36.240 },
	{ 2, 76.790, 36.329 },
	{ 2, 76.680, 36.312 },
	{ 2, 76.675, 36.103 },
	{ 2, 76.576, 36.046 },
	{ 2, 76.446, 36.109 },
	{ 2, 76.380, 36.140 },
	{ 2, 76.271, 36.122 },
	{ 2, 76.260, 36.163 },
	{ 2, 76.206, 36.154 },
	{ 2, 76.086, 36.176 },
	{ 2, 76.175, 36.274 },
	{ 2, 76.120, 36.265 },
	{ 2, 75.965, 36.198 },
	{ 2, 75.989, 36.327 },
	{ 2, 75.910, 36.190 },
	{ 2, 75.811, 36.132 },
	{ 2, 75.889, 36.270 },
	{ 2, 75.968, 36.408 },
	{ 2, 76.012, 36.456 },
	{ 2, 76.112, 36.514 },
	{ 2, 76.047, 36.545 },
	{ 3, 78.543, 33.888 },
	{ 2, 79.682, 34.794 },
	{ 2, 80.793, 34.812 },
	{ 2, 80.769, 34.934 },
	{ 2, 80.863, 35.028 },
	{ 2, 80.956, 35.122 },
	{ 2, 81.026, 35.048 },
	{ 2, 81.073, 35.095 },
	{ 2, 81.003, 35.169 },
	{ 2, 81.893, 35.191 },
	{ 2, 82.400, 35.166 },
	{ 2, 82.571, 35.143 },
	{ 2, 82.749, 35.080 },
	{ 2, 82.988, 34.981 },
	{ 2, 83.104, 34.952 },
	{ 3, 80.876, 32.049 },
	{ 2, 80.801, 32.164 },
	{ 2, 80.688, 32.190 },
	{ 2, 80.734, 32.238 },
	{ 2, 80.771, 32.325 },
	{ 2, 80.801, 32.454 },
	{ 2, 80.605, 32.346 },
	{ 2, 80.477, 32.453 },
	{ 2, 80.522, 32.501 },
	{ 2, 80.356, 32.520 },
	{ 2, 80.182, 32.580 },
	{ 2, 80.121, 32.614 },
	{ 2, 79.939, 32.714 },
	{ 2, 79.923, 32.794 },
	{ 2, 79.817, 32.780 },
	{ 2, 79.625, 32.920 },
	{ 2, 79.548, 33.034 },
	{ 2, 79.372, 33.092 },
	{ 2, 79.257, 33.118 },
	{ 2, 79.188, 33.191 },
	{ 2, 79.224, 33.279 },
	{ 2, 79.252, 33.408 },
	{ 2, 79.145, 33.393 },
	{ 2, 78.934, 33.612 },
	{ 2, 78.792, 33.758 },
	{ 2, 78.606, 33.856 },
	{ 2, 78.543, 33.888 },
	{ 3, 80.876, 32.049 },
	{ 2, 81.026, 32.109 },
	{ 2, 81.124, 32.163 },
	{ 2, 81.110, 32.244 },
	{ 2, 81.178, 32.460 },
	{ 2, 81.413, 32.654 },
	{ 2, 81.392, 32.776 },
	{ 2, 81.461, 32.991 },
	{ 2, 81.759, 33.151 },
	{ 2, 81.852, 33.245 },
	{ 2, 81.930, 33.419 },
	{ 2, 81.923, 33.460 },
	{ 2, 82.016, 33.553 },
	{ 2, 82.210, 33.699 },
	{ 2, 82.404, 33.845 },
	{ 2, 82.593, 34.031 },
	{ 2, 82.735, 34.171 },
	{ 2, 82.870, 34.350 },
	{ 2, 82.905, 34.478 },
	{ 2, 83.068, 34.495 },
	{ 2, 83.272, 34.599 },
	{ 2, 83.368, 34.691 },
	{ 2, 83.355, 34.772 },
	{ 2, 83.104, 34.952 },
	{ 3, 84.981, 31.014 },
	{ 2, 85.069, 31.146 },
	{ 2, 85.095, 31.355 },
	{ 2, 85.063, 31.599 },
	{ 2, 85.099, 31.727 },
	{ 2, 85.136, 31.854 },
	{ 2, 85.073, 31.930 },
	{ 2, 85.051, 32.093 },
	{ 2, 85.046, 32.134 },
	{ 2, 84.924, 32.246 },
	{ 2, 84.871, 32.241 },
	{ 2, 84.966, 32.333 },
	{ 2, 84.955, 32.414 },
	{ 2, 85.087, 32.632 },
	{ 2, 85.167, 32.845 },
	{ 2, 85.301, 33.475 },
	{ 2, 85.541, 34.565 },
	{ 2, 85.603, 34.940 },
	{ 3, 85.603, 34.940 },
	{ 2, 85.379, 34.962 },
	{ 2, 84.326, 34.950 },
	{ 2, 84.326, 34.950 },
	{ 3, 81.540, 30.722 },
	{ 2, 81.467, 30.838 },
	{ 2, 81.453, 30.919 },
	{ 2, 81.490, 31.007 },
	{ 2, 81.379, 31.034 },
	{ 2, 81.417, 31.122 },
	{ 2, 81.469, 31.128 },
	{ 2, 81.507, 31.216 },
	{ 2, 81.410, 31.163 },
	{ 2, 81.389, 31.284 },
	{ 2, 81.374, 31.365 },
	{ 2, 81.322, 31.359 },
	{ 2, 81.256, 31.434 },
	{ 2, 81.182, 31.549 },
	{ 2, 81.234, 31.555 },
	{ 2, 81.174, 31.589 },
	{ 2, 81.100, 31.704 },
	{ 2, 81.145, 31.751 },
	{ 2, 81.026, 31.819 },
	{ 2, 81.063, 31.907 },
	{ 2, 80.951, 31.934 },
	{ 2, 80.824, 32.042 },
	{ 2, 80.876, 32.049 },
	{ 3, 81.540, 30.722 },
	{ 2, 81.636, 30.776 },
	{ 2, 81.792, 30.795 },
	{ 2, 81.888, 30.848 },
	{ 2, 81.947, 30.814 },
	{ 2, 82.006, 30.779 },
	{ 2, 81.995, 30.529 },
	{ 2, 82.022, 30.367 },
	{ 2, 82.125, 30.379 },
	{ 2, 82.201, 30.554 },
	{ 2, 82.195, 30.595 },
	{ 2, 83.087, 30.614 },
	{ 2, 84.078, 30.678 },
	{ 2, 84.862, 30.714 },
	{ 2, 84.903, 30.800 },
	{ 2, 84.981, 31.014 },
	{ 3, 87.416, 30.391 },
	{ 2, 87.360, 30.429 },
	{ 2, 87.451, 30.559 },
	{ 2, 87.391, 30.637 },
	{ 2, 87.439, 30.682 },
	{ 2, 87.627, 30.901 },
	{ 2, 87.619, 30.983 },
	{ 2, 86.775, 31.003 },
	{ 2, 85.455, 31.016 },
	{ 2, 84.981, 31.014 },
	{ 3, 87.416, 30.391 },
	{ 2, 87.476, 30.313 },
	{ 2, 87.368, 30.347 },
	{ 2, 87.256, 30.421 },
	{ 2, 87.191, 30.540 },
	{ 2, 87.140, 30.536 },
	{ 2, 87.040, 30.487 },
	{ 2, 86.984, 30.524 },
	{ 2, 86.988, 30.483 },
	{ 2, 87.152, 30.413 },
	{ 2, 87.100, 30.409 },
	{ 2, 86.733, 30.422 },
	{ 2, 86.516, 30.487 },
	{ 2, 86.460, 30.524 },
	{ 2, 86.361, 30.475 },
	{ 2, 86.200, 30.503 },
	{ 2, 86.106, 30.412 },
	{ 2, 86.309, 30.471 },
	{ 2, 86.469, 30.442 },
	{ 2, 86.422, 30.397 },
	{ 2, 85.965, 30.277 },
	{ 2, 85.711, 30.213 },
	{ 2, 85.758, 30.259 },
	{ 2, 85.805, 30.304 },
	{ 2, 85.707, 30.254 },
	{ 2, 85.711, 30.213 },
	{ 2, 85.561, 30.159 },
	{ 2, 85.520, 30.072 },
	{ 2, 85.525, 30.031 },
	{ 2, 85.375, 29.977 },
	{ 2, 85.298, 29.763 },
	{ 2, 85.391, 29.854 },
	{ 2, 85.442, 29.859 },
	{ 2, 85.359, 29.686 },
	{ 2, 85.195, 29.753 },
	{ 2, 84.984, 29.775 },
	{ 2, 84.876, 29.806 },
	{ 2, 84.882, 29.765 },
	{ 2, 84.495, 29.934 },
	{ 2, 84.392, 29.924 },
	{ 2, 84.335, 29.960 },
	{ 2, 84.329, 30.000 },
	{ 2, 84.267, 30.077 },
	{ 2, 84.209, 30.112 },
	{ 2, 84.049, 30.137 },
	{ 2, 83.758, 29.983 },
	{ 2, 83.570, 29.838 },
	{ 2, 83.531, 29.751 },
	{ 2, 83.383, 29.694 },
	{ 2, 83.356, 29.525 },
	{ 2, 83.260, 29.473 },
	{ 2, 83.119, 29.374 },
	{ 2, 83.029, 29.281 },
	{ 2, 82.934, 29.229 },
	{ 2, 82.781, 29.211 },
	{ 2, 82.794, 29.130 },
	{ 2, 82.698, 29.077 },
	{ 2, 82.660, 28.989 },
	{ 2, 82.622, 28.902 },
	{ 2, 82.628, 28.861 },
	{ 2, 82.591, 28.773 },
	{ 2, 82.610, 28.651 },
	{ 2, 82.635, 28.487 },
	{ 2, 82.710, 28.330 },
	{ 2, 82.735, 28.166 },
	{ 2, 82.823, 27.927 },
	{ 2, 82.729, 27.874 },
	{ 2, 82.691, 27.786 },
	{ 2, 82.591, 27.774 },
	{ 2, 82.623, 27.903 },
	{ 2, 82.660, 27.991 },
	{ 2, 82.648, 28.073 },
	{ 2, 82.554, 28.020 },
	{ 2, 82.516, 27.932 },
	{ 2, 82.460, 27.967 },
	{ 2, 82.353, 27.996 },
	{ 2, 82.379, 27.832 },
	{ 2, 82.441, 27.756 },
	{ 2, 82.510, 27.640 },
	{ 2, 82.523, 27.558 },
	{ 2, 82.623, 27.570 },
	{ 2, 82.635, 27.488 },
	{ 2, 82.505, 27.347 },
	{ 2, 82.437, 27.130 },
	{ 2, 82.264, 26.942 },
	{ 2, 82.171, 26.888 },
	{ 2, 82.201, 27.017 },
	{ 2, 82.195, 27.058 },
	{ 2, 82.102, 27.005 },
	{ 2, 81.997, 27.033 },
	{ 2, 82.059, 26.958 },
	{ 2, 82.049, 26.706 },
	{ 2, 81.963, 26.611 },
	{ 2, 81.927, 26.523 },
	{ 2, 81.835, 26.469 },
	{ 2, 81.776, 26.210 },
	{ 2, 81.711, 25.992 },
	{ 2, 81.613, 25.979 },
	{ 2, 81.466, 25.960 },
	{ 2, 81.291, 25.810 },
	{ 2, 81.172, 25.626 },
	{ 2, 81.095, 25.489 },
	{ 2, 80.956, 25.428 },
	{ 2, 80.859, 25.414 },
	{ 2, 80.872, 25.332 },
	{ 2, 81.018, 25.352 },
	{ 2, 81.115, 25.366 },
	{ 2, 81.122, 25.325 },
	{ 2, 81.045, 25.188 },
	{ 2, 80.942, 25.216 },
	{ 2, 80.741, 25.229 },
	{ 2, 80.533, 25.284 },
	{ 2, 80.381, 25.304 },
	{ 2, 80.318, 25.379 },
	{ 2, 80.282, 25.584 },
	{ 2, 80.212, 25.700 },
	{ 2, 80.134, 25.857 },
	{ 2, 80.085, 25.850 },
	{ 2, 80.070, 25.932 },
	{ 2, 80.026, 26.177 },
	{ 2, 79.987, 26.675 },
	{ 2, 80.018, 27.057 },
	{ 2, 80.137, 27.242 },
	{ 2, 80.291, 27.515 },
	{ 2, 80.389, 27.822 },
	{ 2, 80.573, 28.224 },
	{ 2, 80.716, 28.577 },
	{ 2, 80.831, 28.801 },
	{ 2, 80.730, 28.788 },
	{ 2, 80.882, 29.100 },
	{ 2, 80.962, 29.235 },
	{ 2, 81.137, 29.716 },
	{ 2, 81.211, 29.892 },
	{ 2, 81.352, 30.284 },
	{ 2, 81.434, 30.419 },
	{ 2, 81.413, 30.541 },
	{ 2, 81.436, 30.710 },
	{ 2, 81.488, 30.716 },
	{ 2, 81.540, 30.722 },
	{ 3, 88.354, 30.414 },
	{ 2, 88.302, 30.411 },
	{ 2, 88.154, 30.319 },
	{ 2, 88.079, 30.561 },
	{ 2, 88.068, 30.684 },
	{ 2, 88.004, 30.803 },
	{ 2, 87.956, 30.759 },
	{ 2, 87.912, 30.673 },
	{ 2, 87.919, 30.592 },
	{ 2, 87.883, 30.424 },
	{ 2, 87.831, 30.421 },
	{ 2, 87.791, 30.294 },
	{ 2, 87.950, 30.264 },
	{ 2, 88.006, 30.227 },
	{ 2, 87.584, 30.280 },
	{ 2, 87.472, 30.354 },
	{ 2, 87.416, 30.391 },
	{ 3, 88.354, 30.414 },
	{ 2, 88.423, 31.407 },
	{ 2, 88.489, 31.863 },
	{ 2, 88.343, 32.881 },
	{ 2, 88.233, 34.064 },
	{ 2, 88.100, 34.876 },
	{ 2, 88.151, 34.920 },
	{ 2, 88.202, 34.964 },
	{ 3, 88.202, 34.964 },
	{ 2, 87.259, 34.984 },
	{ 2, 85.603, 34.940 },
	{ 3, 89.522, 30.154 },
	{ 2, 89.409, 30.272 },
	{ 2, 89.299, 30.348 },
	{ 2, 89.143, 30.339 },
	{ 2, 88.877, 30.406 },
	{ 2, 88.773, 30.399 },
	{ 2, 88.725, 30.355 },
	{ 2, 88.617, 30.390 },
	{ 2, 88.517, 30.342 },
	{ 2, 88.354, 30.414 },
	{ 3, 89.522, 30.154 },
	{ 2, 89.617, 30.283 },
	{ 2, 89.709, 30.452 },
	{ 2, 89.755, 30.537 },
	{ 2, 89.795, 30.704 },
	{ 2, 89.725, 30.947 },
	{ 2, 89.722, 30.988 },
	{ 2, 90.827, 30.957 },
	{ 2, 91.613, 30.988 },
	{ 2, 91.558, 31.027 },
	{ 2, 91.601, 31.234 },
	{ 2, 91.542, 31.355 },
	{ 2, 91.485, 31.435 },
	{ 2, 91.426, 31.556 },
	{ 2, 91.426, 31.556 },
	{ 2, 91.477, 31.599 },
	{ 2, 91.369, 31.636 },
	{ 2, 91.256, 31.755 },
	{ 2, 91.252, 31.837 },
	{ 2, 91.195, 31.917 },
	{ 2, 91.135, 32.037 },
	{ 2, 90.971, 32.113 },
	{ 2, 90.968, 32.154 },
	{ 2, 91.130, 32.119 },
	{ 2, 91.072, 32.199 },
	{ 2, 90.966, 32.195 },
	{ 2, 90.905, 32.315 },
	{ 2, 91.112, 32.447 },
	{ 2, 91.002, 32.483 },
	{ 2, 91.049, 32.608 },
	{ 2, 91.153, 32.653 },
	{ 2, 91.149, 32.735 },
	{ 2, 91.086, 32.896 },
	{ 2, 91.191, 32.941 },
	{ 2, 91.191, 32.941 },
	{ 3, 91.191, 32.941 },
	{ 2, 92.050, 32.971 },
	{ 2, 93.502, 32.966 },
	{ 2, 94.039, 32.974 },
	{ 3, 91.191, 32.941 },
	{ 2, 91.132, 33.021 },
	{ 2, 91.072, 33.142 },
	{ 2, 91.065, 33.264 },
	{ 2, 91.172, 33.269 },
	{ 2, 91.111, 33.389 },
	{ 2, 91.222, 33.352 },
	{ 2, 91.163, 33.432 },
	{ 2, 91.215, 33.475 },
	{ 2, 91.156, 33.555 },
	{ 2, 91.203, 33.679 },
	{ 2, 91.095, 33.675 },
	{ 2, 91.149, 33.677 },
	{ 2, 91.085, 33.839 },
	{ 2, 91.078, 33.961 },
	{ 2, 90.967, 33.998 },
	{ 2, 90.905, 34.118 },
	{ 2, 90.903, 34.159 },
	{ 2, 90.789, 34.236 },
	{ 2, 90.726, 34.357 },
	{ 2, 90.560, 34.391 },
	{ 2, 90.604, 34.556 },
	{ 2, 90.492, 34.592 },
	{ 2, 90.538, 34.717 },
	{ 2, 90.426, 34.753 },
	{ 2, 90.253, 34.869 },
	{ 2, 90.302, 34.953 },
	{ 3, 90.302, 34.953 },
	{ 2, 90.299, 34.993 },
	{ 2, 90.186, 35.029 },
	{ 2, 90.070, 35.106 },
	{ 2, 90.111, 35.313 },
	{ 2, 90.221, 35.318 },
	{ 2, 90.157, 35.437 },
	{ 2, 90.052, 35.351 },
	{ 2, 89.933, 35.468 },
	{ 2, 89.865, 35.629 },
	{ 2, 89.859, 35.710 },
	{ 2, 89.741, 35.787 },
	{ 2, 89.676, 35.906 },
	{ 2, 89.729, 35.950 },
	{ 3, 90.302, 34.953 },
	{ 2, 89.639, 34.962 },
	{ 2, 88.425, 34.937 },
	{ 2, 88.202, 34.964 },
	{ 3, 89.729, 35.950 },
	{ 2, 90.007, 35.963 },
	{ 2, 90.401, 35.939 },
	{ 2, 90.219, 36.136 },
	{ 2, 90.092, 36.335 },
	{ 2, 90.195, 36.463 },
	{ 2, 90.591, 36.439 },
	{ 2, 91.492, 36.432 },
	{ 2, 92.785, 36.428 },
	{ 2, 93.347, 36.440 },
	{ 2, 94.078, 36.410 },
	{ 2, 94.639, 36.457 },
	{ 3, 89.729, 35.950 },
	{ 2, 89.667, 36.029 },
	{ 2, 89.601, 36.148 },
	{ 2, 89.710, 36.194 },
	{ 2, 89.595, 36.230 },
	{ 2, 89.647, 36.273 },
	{ 2, 89.529, 36.349 },
	{ 2, 89.572, 36.515 },
	{ 2, 89.516, 36.513 },
	{ 2, 89.469, 36.387 },
	{ 2, 89.407, 36.466 },
	{ 3, 89.407, 36.466 },
	{ 2, 89.340, 36.586 },
	{ 2, 89.288, 36.542 },
	{ 2, 89.175, 36.536 },
	{ 2, 89.168, 36.618 },
	{ 2, 89.158, 36.740 },
	{ 2, 89.087, 36.900 },
	{ 2, 89.197, 36.947 },
	{ 3, 89.407, 36.466 },
	{ 2, 89.410, 36.425 },
	{ 2, 88.506, 36.458 },
	{ 2, 88.053, 36.472 },
	{ 2, 88.093, 36.638 },
	{ 2, 87.648, 36.569 },
	{ 2, 86.625, 36.622 },
	{ 2, 86.232, 36.592 },
	{ 2, 84.990, 36.573 },
	{ 2, 83.692, 36.536 },
	{ 2, 83.685, 36.577 },
	{ 3, 89.197, 36.947 },
	{ 2, 89.303, 37.034 },
	{ 2, 89.366, 36.956 },
	{ 2, 89.462, 37.165 },
	{ 2, 89.512, 37.250 },
	{ 2, 89.452, 37.288 },
	{ 2, 89.542, 37.579 },
	{ 2, 89.757, 37.753 },
	{ 2, 90.033, 37.889 },
	{ 2, 89.976, 37.886 },
	{ 2, 90.196, 38.019 },
	{ 2, 90.408, 38.274 },
	{ 2, 90.217, 38.512 },
	{ 2, 90.202, 38.716 },
	{ 2, 90.141, 38.754 },
	{ 2, 90.309, 38.844 },
	{ 2, 90.480, 38.892 },
	{ 2, 90.602, 38.815 },
	{ 2, 90.660, 38.817 },
	{ 2, 90.709, 38.942 },
	{ 2, 90.809, 39.192 },
	{ 2, 91.090, 39.366 },
	{ 2, 91.255, 39.536 },
	{ 2, 91.475, 39.790 },
	{ 2, 91.518, 40.078 },
	{ 2, 91.447, 40.281 },
	{ 3, 89.197, 36.947 },
	{ 2, 89.066, 37.145 },
	{ 2, 88.783, 37.130 },
	{ 2, 88.508, 37.032 },
	{ 2, 88.545, 37.239 },
	{ 2, 88.416, 37.396 },
	{ 2, 88.124, 37.461 },
	{ 2, 88.169, 37.586 },
	{ 2, 88.104, 37.664 },
	{ 2, 88.039, 37.743 },
	{ 3, 88.039, 37.743 },
	{ 2, 88.087, 37.828 },
	{ 2, 88.075, 37.950 },
	{ 2, 88.001, 38.110 },
	{ 2, 87.931, 38.228 },
	{ 2, 87.808, 38.303 },
	{ 2, 87.728, 38.503 },
	{ 2, 87.538, 38.655 },
	{ 2, 87.569, 38.904 },
	{ 2, 87.662, 39.115 },
	{ 2, 87.649, 39.238 },
	{ 2, 87.582, 39.316 },
	{ 2, 87.554, 40.095 },
	{ 2, 87.603, 41.252 },
	{ 2, 87.617, 41.665 },
	{ 3, 88.039, 37.743 },
	{ 2, 87.982, 37.739 },
	{ 2, 87.973, 37.821 },
	{ 2, 87.855, 37.854 },
	{ 2, 87.692, 37.762 },
	{ 2, 87.618, 37.921 },
	{ 2, 87.508, 37.873 },
	{ 2, 87.284, 37.817 },
	{ 2, 87.123, 37.724 },
	{ 2, 87.113, 37.806 },
	{ 2, 86.866, 37.953 },
	{ 2, 86.705, 37.860 },
	{ 2, 86.586, 37.892 },
	{ 2, 86.457, 38.006 },
	{ 2, 86.389, 38.083 },
	{ 2, 86.327, 38.120 },
	{ 2, 86.171, 37.985 },
	{ 2, 86.000, 37.972 },
	{ 2, 85.916, 38.171 },
	{ 2, 85.665, 38.316 },
	{ 2, 85.471, 38.465 },
	{ 2, 85.506, 38.632 },
	{ 2, 85.437, 38.709 },
	{ 2, 85.322, 38.699 },
	{ 2, 85.213, 38.649 },
	{ 2, 84.965, 38.752 },
	{ 2, 84.850, 38.742 },
	{ 2, 84.838, 38.824 },
	{ 2, 84.878, 38.951 },
	{ 2, 84.929, 38.996 },
	{ 2, 84.860, 39.073 },
	{ 3, 84.860, 39.073 },
	{ 2, 84.796, 39.108 },
	{ 2, 84.628, 39.053 },
	{ 2, 84.507, 39.083 },
	{ 2, 84.455, 39.038 },
	{ 2, 84.249, 38.854 },
	{ 2, 84.204, 38.768 },
	{ 2, 84.032, 38.752 },
	{ 2, 83.757, 38.644 },
	{ 2, 83.578, 38.668 },
	{ 2, 83.406, 38.652 },
	{ 2, 83.298, 38.600 },
	{ 2, 83.112, 38.664 },
	{ 2, 82.926, 38.728 },
	{ 2, 82.890, 38.601 },
	{ 2, 82.632, 38.409 },
	{ 2, 82.575, 38.403 },
	{ 3, 84.860, 39.073 },
	{ 2, 84.886, 39.693 },
	{ 2, 84.857, 40.681 },
	{ 2, 84.853, 41.508 },
	{ 2, 84.828, 41.671 },
	{ 3, 84.828, 41.671 },
	{ 2, 83.849, 41.711 },
	{ 2, 83.483, 41.719 },
	{ 3, 83.483, 41.719 },
	{ 2, 83.462, 41.841 },
	{ 2, 83.261, 41.947 },
	{ 2, 83.232, 42.110 },
	{ 2, 83.203, 42.274 },
	{ 2, 83.075, 42.303 },
	{ 2, 82.925, 42.455 },
	{ 2, 82.903, 42.577 },
	{ 2, 82.835, 42.612 },
	{ 2, 82.706, 42.641 },
	{ 2, 82.781, 42.566 },
	{ 2, 82.728, 42.519 },
	{ 2, 82.653, 42.595 },
	{ 2, 82.607, 42.840 },
	{ 2, 82.523, 42.957 },
	{ 2, 82.554, 43.126 },
	{ 2, 82.622, 43.425 },
	{ 2, 82.684, 43.764 },
	{ 2, 82.892, 43.993 },
	{ 2, 83.139, 44.016 },
	{ 2, 83.347, 43.910 },
	{ 2, 83.423, 43.834 },
	{ 2, 83.637, 43.686 },
	{ 2, 83.788, 43.533 },
	{ 2, 84.021, 43.637 },
	{ 2, 83.979, 43.883 },
	{ 2, 83.903, 43.960 },
	{ 2, 83.780, 43.949 },
	{ 2, 83.627, 44.103 },
	{ 2, 83.606, 44.226 },
	{ 2, 83.482, 44.215 },
	{ 2, 83.445, 44.420 },
	{ 2, 83.401, 44.667 },
	{ 2, 83.552, 44.890 },
	{ 2, 83.538, 44.972 },
	{ 2, 83.531, 45.014 },
	{ 2, 83.405, 45.002 },
	{ 2, 83.509, 45.137 },
	{ 2, 83.605, 45.313 },
	{ 2, 83.970, 45.429 },
	{ 2, 84.216, 45.492 },
	{ 2, 84.385, 45.632 },
	{ 2, 84.816, 45.750 },
	{ 2, 84.949, 45.719 },
	{ 2, 85.077, 45.729 },
	{ 2, 85.026, 45.641 },
	{ 2, 85.172, 45.527 },
	{ 2, 85.008, 45.346 },
	{ 2, 85.267, 45.324 },
	{ 2, 85.469, 45.256 },
	{ 2, 85.462, 44.879 },
	{ 2, 85.611, 44.724 },
	{ 2, 85.581, 44.930 },
	{ 2, 85.575, 44.971 },
	{ 2, 85.662, 44.811 },
	{ 2, 85.674, 44.728 },
	{ 2, 85.731, 44.774 },
	{ 2, 85.719, 44.857 },
	{ 2, 85.689, 45.063 },
	{ 2, 85.614, 45.141 },
	{ 2, 85.683, 45.105 },
	{ 2, 85.964, 44.916 },
	{ 2, 86.102, 44.842 },
	{ 2, 86.187, 44.681 },
	{ 2, 86.256, 44.645 },
	{ 2, 86.267, 44.562 },
	{ 2, 86.374, 44.236 },
	{ 2, 86.588, 44.043 },
	{ 2, 86.507, 43.705 },
	{ 2, 86.585, 43.585 },
	{ 2, 86.540, 43.458 },
	{ 2, 86.337, 43.112 },
	{ 2, 86.265, 42.734 },
	{ 2, 86.226, 42.565 },
	{ 2, 86.314, 42.364 },
	{ 2, 86.609, 41.971 },
	{ 2, 86.690, 41.812 },
	{ 2, 86.816, 41.779 },
	{ 2, 86.886, 41.701 },
	{ 3, 87.617, 41.665 },
	{ 2, 87.663, 41.792 },
	{ 2, 87.761, 42.004 },
	{ 2, 87.812, 42.090 },
	{ 2, 87.920, 42.220 },
	{ 2, 87.841, 42.381 },
	{ 2, 87.836, 42.422 },
	{ 3, 86.886, 41.701 },
	{ 2, 87.076, 41.631 },
	{ 2, 87.446, 41.572 },
	{ 2, 87.617, 41.665 },
	{ 3, 86.886, 41.701 },
	{ 2, 86.580, 41.721 },
	{ 2, 85.248, 41.705 },
	{ 2, 84.882, 41.717 },
	{ 2, 84.828, 41.671 },
	{ 3, 91.447, 40.281 },
	{ 2, 91.563, 40.326 },
	{ 2, 91.729, 40.536 },
	{ 2, 91.967, 40.543 },
	{ 2, 93.393, 40.535 },
	{ 2, 94.700, 40.510 },
	{ 2, 95.768, 40.514 },
	{ 3, 91.447, 40.281 },
	{ 2, 91.445, 40.322 },
	{ 2, 91.494, 40.488 },
	{ 2, 91.190, 40.601 },
	{ 2, 90.996, 40.841 },
	{ 2, 90.983, 41.046 },
	{ 2, 91.100, 41.091 },
	{ 2, 91.157, 41.134 },
	{ 2, 91.089, 41.255 },
	{ 2, 91.084, 41.337 },
	{ 2, 90.901, 41.372 },
	{ 2, 90.533, 41.482 },
	{ 2, 90.406, 41.559 },
	{ 2, 90.337, 41.680 },
	{ 2, 90.210, 41.757 },
	{ 2, 90.201, 41.880 },
	{ 2, 90.188, 42.045 },
	{ 2, 90.306, 42.091 },
	{ 2, 90.482, 42.180 },
	{ 2, 90.534, 42.306 },
	{ 2, 90.707, 42.436 },
	{ 3, 90.707, 42.436 },
	{ 2, 90.704, 42.477 },
	{ 2, 90.821, 42.564 },
	{ 2, 90.940, 42.610 },
	{ 2, 91.118, 42.699 },
	{ 2, 91.171, 42.824 },
	{ 2, 91.219, 43.032 },
	{ 2, 91.150, 43.154 },
	{ 2, 91.260, 43.364 },
	{ 2, 91.319, 43.408 },
	{ 3, 90.707, 42.436 },
	{ 2, 89.426, 42.423 },
	{ 2, 88.262, 42.446 },
	{ 2, 87.836, 42.422 },
	{ 3, 87.836, 42.422 },
	{ 2, 87.879, 42.590 },
	{ 2, 87.865, 42.713 },
	{ 2, 87.917, 42.799 },
	{ 2, 87.956, 43.008 },
	{ 2, 87.933, 43.214 },
	{ 2, 87.840, 43.498 },
	{ 2, 87.759, 43.660 },
	{ 2, 87.807, 43.787 },
	{ 2, 87.722, 43.990 },
	{ 2, 87.578, 44.147 },
	{ 2, 87.568, 44.230 },
	{ 2, 87.529, 44.560 },
	{ 2, 87.312, 44.797 },
	{ 2, 87.223, 45.000 },
	{ 2, 87.076, 45.158 },
	{ 2, 87.129, 45.244 },
	{ 2, 87.271, 45.128 },
	{ 2, 87.344, 45.049 },
	{ 2, 87.437, 44.805 },
	{ 2, 87.563, 44.812 },
	{ 2, 87.631, 44.774 },
	{ 2, 87.905, 44.582 },
	{ 2, 87.973, 44.544 },
	{ 2, 87.982, 44.462 },
	{ 2, 88.103, 44.510 },
	{ 2, 88.084, 44.676 },
	{ 2, 87.873, 44.872 },
	{ 2, 87.669, 44.985 },
	{ 2, 87.665, 45.026 },
	{ 3, 90.536, 46.500 },
	{ 2, 90.727, 46.549 },
	{ 2, 90.924, 46.514 },
	{ 2, 90.985, 46.558 },
	{ 2, 90.912, 46.681 },
	{ 2, 90.900, 46.849 },
	{ 2, 91.098, 46.813 },
	{ 2, 91.495, 46.700 },
	{ 2, 91.891, 46.586 },
	{ 2, 92.148, 46.634 },
	{ 2, 92.275, 46.679 },
	{ 3, 87.665, 45.026 },
	{ 2, 87.362, 45.426 },
	{ 2, 87.141, 45.663 },
	{ 2, 87.051, 45.867 },
	{ 2, 87.077, 45.659 },
	{ 2, 86.865, 45.813 },
	{ 2, 86.668, 45.842 },
	{ 2, 86.759, 45.639 },
	{ 2, 86.707, 45.552 },
	{ 2, 86.621, 45.713 },
	{ 2, 86.419, 45.784 },
	{ 2, 86.274, 45.900 },
	{ 2, 85.949, 45.919 },
	{ 2, 85.752, 45.947 },
	{ 2, 85.676, 46.025 },
	{ 2, 85.357, 46.002 },
	{ 2, 85.044, 45.936 },
	{ 2, 84.866, 45.838 },
	{ 2, 84.789, 45.916 },
	{ 2, 84.776, 45.999 },
	{ 2, 84.648, 45.989 },
	{ 2, 84.521, 45.978 },
	{ 2, 84.337, 45.921 },
	{ 2, 84.146, 45.905 },
	{ 2, 84.004, 45.978 },
	{ 2, 84.181, 46.077 },
	{ 2, 84.366, 46.134 },
	{ 2, 84.388, 46.388 },
	{ 2, 84.445, 46.435 },
	{ 2, 84.581, 46.404 },
	{ 2, 84.773, 46.419 },
	{ 2, 84.908, 46.387 },
	{ 2, 85.152, 46.490 },
	{ 2, 85.055, 46.693 },
	{ 2, 85.248, 46.708 },
	{ 2, 85.654, 46.612 },
	{ 2, 85.976, 46.634 },
	{ 2, 86.240, 46.611 },
	{ 2, 86.579, 46.507 },
	{ 2, 86.730, 46.349 },
	{ 2, 86.848, 46.441 },
	{ 2, 86.982, 46.407 },
	{ 2, 87.170, 46.461 },
	{ 2, 87.368, 46.431 },
	{ 2, 87.492, 46.480 },
	{ 2, 87.611, 46.571 },
	{ 2, 87.720, 46.745 },
	{ 2, 87.845, 46.794 },
	{ 2, 88.099, 46.850 },
	{ 2, 88.303, 46.777 },
	{ 2, 88.224, 46.899 },
	{ 2, 88.492, 46.829 },
	{ 2, 88.570, 46.707 },
	{ 2, 88.566, 46.749 },
	{ 2, 88.548, 46.916 },
	{ 2, 88.475, 46.996 },
	{ 2, 88.331, 47.115 },
	{ 2, 88.052, 47.268 },
	{ 2, 87.846, 47.341 },
	{ 2, 87.841, 47.383 },
	{ 2, 87.967, 47.432 },
	{ 2, 88.233, 47.404 },
	{ 2, 88.439, 47.331 },
	{ 2, 88.578, 47.254 },
	{ 2, 88.787, 47.138 },
	{ 2, 88.994, 47.022 },
	{ 2, 89.003, 46.939 },
	{ 2, 89.198, 46.948 },
	{ 2, 89.408, 46.789 },
	{ 2, 89.736, 46.762 },
	{ 2, 89.865, 46.767 },
	{ 2, 90.002, 46.689 },
	{ 2, 90.138, 46.611 },
	{ 2, 90.339, 46.535 },
	{ 2, 90.536, 46.500 },
	{ 3, 87.665, 45.026 },
	{ 2, 87.723, 45.072 },
	{ 2, 87.762, 45.282 },
	{ 2, 87.952, 45.293 },
	{ 2, 87.947, 45.335 },
	{ 2, 87.924, 45.542 },
	{ 2, 87.969, 45.712 },
	{ 2, 88.224, 45.726 },
	{ 2, 88.210, 45.851 },
	{ 2, 88.461, 45.906 },
	{ 2, 88.781, 45.922 },
	{ 2, 89.093, 46.021 },
	{ 2, 89.976, 46.227 },
	{ 2, 90.230, 46.279 },
	{ 2, 90.288, 46.365 },
	{ 2, 90.410, 46.454 },
	{ 2, 90.536, 46.500 },
	{ 3, 91.319, 43.408 },
	{ 2, 91.255, 43.447 },
	{ 2, 91.304, 43.655 },
	{ 2, 91.415, 43.866 },
	{ 2, 91.717, 44.041 },
	{ 2, 91.955, 44.255 },
	{ 2, 92.387, 44.391 },
	{ 2, 92.446, 44.475 },
	{ 2, 92.632, 44.521 },
	{ 2, 92.877, 44.692 },
	{ 2, 92.810, 44.774 },
	{ 2, 92.860, 45.107 },
	{ 2, 92.788, 45.314 },
	{ 2, 92.844, 45.481 },
	{ 2, 93.034, 45.527 },
	{ 2, 92.832, 45.773 },
	{ 2, 92.569, 45.934 },
	{ 2, 92.372, 46.013 },
	{ 2, 92.368, 46.096 },
	{ 2, 92.356, 46.347 },
	{ 2, 92.409, 46.599 },
	{ 2, 92.275, 46.679 },
	{ 3, 92.275, 46.679 },
	{ 2, 91.874, 46.879 },
	{ 2, 91.472, 47.077 },
	{ 2, 91.262, 47.280 },
	{ 2, 90.784, 47.559 },
	{ 2, 89.972, 47.823 },
	{ 2, 89.561, 47.975 },
	{ 2, 89.825, 47.986 },
	{ 2, 89.961, 47.949 },
	{ 2, 90.089, 47.996 },
	{ 2, 90.218, 48.044 },
	{ 2, 90.416, 48.051 },
	{ 2, 90.813, 48.065 },
	{ 2, 90.936, 48.196 },
	{ 2, 91.138, 48.161 },
	{ 2, 91.545, 48.004 },
	{ 2, 91.741, 48.052 },
	{ 2, 91.869, 48.140 },
	{ 2, 92.129, 48.231 },
	{ 2, 92.191, 48.317 },
	{ 2, 92.326, 48.278 },
	{ 2, 92.396, 48.196 },
	{ 2, 92.465, 48.155 },
	{ 2, 92.525, 48.283 },
	{ 2, 92.585, 48.411 },
	{ 2, 92.785, 48.415 },
	{ 2, 92.715, 48.498 },
	{ 2, 92.914, 48.502 },
	{ 2, 93.311, 48.594 },
	{ 2, 93.849, 48.433 },
	{ 2, 93.913, 48.560 },
	{ 2, 94.313, 48.565 },
	{ 2, 94.445, 48.651 },
	{ 2, 94.512, 48.609 },
	{ 2, 94.778, 48.695 },
	{ 2, 94.777, 48.780 },
	{ 2, 94.839, 49.119 },
	{ 2, 94.905, 49.290 },
	{ 2, 94.972, 49.290 },
	{ 2, 95.241, 49.333 },
	{ 2, 95.244, 48.952 },
	{ 2, 97.323, 48.943 },
	{ 3, 91.319, 43.408 },
	{ 2, 91.690, 43.419 },
	{ 2, 93.113, 43.413 },
	{ 2, 94.906, 43.435 },
	{ 2, 96.452, 43.393 },
	{ 3, 96.452, 43.393 },
	{ 2, 96.464, 44.469 },
	{ 2, 96.473, 45.217 },
	{ 2, 96.794, 45.423 },
	{ 2, 96.860, 45.589 },
	{ 2, 96.734, 45.673 },
	{ 2, 96.608, 45.841 },
	{ 2, 96.608, 45.841 },
	{ 3, 96.452, 43.393 },
	{ 2, 96.638, 43.392 },
	{ 2, 96.575, 43.310 },
	{ 2, 96.634, 43.144 },
	{ 2, 96.510, 43.063 },
	{ 2, 96.509, 42.980 },
	{ 2, 96.570, 42.938 },
	{ 2, 96.568, 42.773 },
	{ 2, 96.628, 42.690 },
	{ 2, 96.626, 42.567 },
	{ 2, 96.502, 42.403 },
	{ 3, 96.608, 45.841 },
	{ 2, 99.043, 45.844 },
	{ 2, 103.022, 45.856 },
	{ 2, 104.119, 45.830 },
	{ 3, 96.608, 45.841 },
	{ 2, 96.610, 45.966 },
	{ 2, 96.679, 46.257 },
	{ 2, 96.878, 46.590 },
	{ 2, 96.817, 46.842 },
	{ 2, 96.885, 46.967 },
	{ 2, 96.888, 47.177 },
	{ 2, 96.893, 47.428 },
	{ 2, 96.961, 47.554 },
	{ 2, 97.098, 47.805 },
	{ 2, 97.235, 48.056 },
	{ 2, 97.241, 48.309 },
	{ 2, 97.246, 48.520 },
	{ 2, 97.182, 48.606 },
	{ 2, 97.250, 48.690 },
	{ 2, 97.323, 48.943 },
	{ 3, 97.323, 48.943 },
	{ 2, 99.605, 48.940 },
	{ 2,102.089, 48.935 },
	{ 2,104.105, 48.914 },
	{ 3,104.112, 45.836 },
	{ 2,104.105, 48.914 },
	{ 3,104.105, 48.914 },
	{ 2,106.125, 48.908 },
	{ 2,108.284, 48.903 },
	{ 2,109.770, 48.890 },
	{ 2,112.552, 48.885 },
	{ 2,114.334, 48.919 },
	{ 2,116.038, 48.898 },
	{ 3,104.067, 42.884 },
	{ 2,104.126, 44.916 },
	{ 3,104.126, 44.916 },
	{ 2,104.112, 45.836 },
	{ 3,104.126, 44.916 },
	{ 2,105.967, 44.915 },
	{ 2,107.361, 44.886 },
	{ 2,108.824, 44.878 },
	{ 2,110.037, 44.881 },
	{ 2,111.062, 44.895 },
	{ 2,111.076, 44.389 },
	{ 3, 96.502, 42.403 },
	{ 2, 96.563, 42.361 },
	{ 2, 96.624, 42.402 },
	{ 2, 96.810, 42.565 },
	{ 2, 96.995, 42.646 },
	{ 2, 97.179, 42.685 },
	{ 2, 97.302, 42.725 },
	{ 2, 97.487, 42.764 },
	{ 2, 97.731, 42.719 },
	{ 2, 97.916, 42.758 },
	{ 2, 97.976, 42.715 },
	{ 2, 98.097, 42.672 },
	{ 2, 98.222, 42.752 },
	{ 2, 98.470, 42.830 },
	{ 2, 98.535, 42.911 },
	{ 2, 99.332, 42.891 },
	{ 2,103.022, 42.905 },
	{ 2,104.067, 42.884 },
	{ 3,104.076, 40.901 },
	{ 2,104.067, 42.884 },
	{ 3, 96.502, 42.403 },
	{ 2, 96.441, 42.362 },
	{ 2, 96.378, 42.156 },
	{ 2, 96.377, 42.074 },
	{ 2, 96.254, 41.910 },
	{ 2, 96.193, 41.787 },
	{ 2, 96.191, 41.540 },
	{ 2, 96.131, 41.458 },
	{ 2, 96.010, 41.335 },
	{ 2, 95.949, 41.253 },
	{ 2, 95.949, 41.089 },
	{ 2, 95.888, 40.924 },
	{ 2, 95.888, 40.719 },
	{ 2, 95.888, 40.678 },
	{ 2, 95.828, 40.555 },
	{ 2, 95.768, 40.514 },
	{ 3, 95.768, 40.514 },
	{ 2, 95.768, 40.432 },
	{ 2, 95.591, 40.186 },
	{ 2, 95.355, 39.939 },
	{ 2, 95.355, 39.939 },
	{ 3, 95.355, 39.939 },
	{ 2, 96.297, 39.897 },
	{ 2, 98.005, 39.919 },
	{ 2, 99.655, 39.920 },
	{ 2,101.363, 39.897 },
	{ 2,102.071, 39.904 },
	{ 3,102.071, 39.904 },
	{ 2,102.099, 40.890 },
	{ 2,103.417, 40.901 },
	{ 2,104.076, 40.901 },
	{ 3, 94.639, 36.457 },
	{ 2, 94.538, 35.680 },
	{ 2, 94.432, 35.351 },
	{ 2, 94.501, 34.453 },
	{ 2, 94.514, 33.594 },
	{ 3, 94.639, 36.457 },
	{ 2, 94.637, 36.621 },
	{ 2, 94.632, 36.948 },
	{ 3, 94.632, 36.948 },
	{ 2, 96.556, 36.908 },
	{ 2, 98.366, 36.923 },
	{ 2,100.120, 36.913 },
	{ 2,102.045, 36.912 },
	{ 3, 94.632, 36.948 },
	{ 2, 94.680, 37.602 },
	{ 2, 94.665, 38.748 },
	{ 2, 94.602, 39.075 },
	{ 2, 94.718, 39.117 },
	{ 2, 94.835, 39.118 },
	{ 2, 94.949, 39.323 },
	{ 2, 95.123, 39.488 },
	{ 2, 94.946, 39.651 },
	{ 2, 94.945, 39.774 },
	{ 2, 95.003, 39.774 },
	{ 2, 95.003, 39.856 },
	{ 2, 95.238, 39.816 },
	{ 2, 95.355, 39.939 },
	{ 3,102.045, 36.912 },
	{ 2,102.071, 39.904 },
	{ 3, 94.514, 33.594 },
	{ 2, 94.676, 33.636 },
	{ 2, 94.946, 33.802 },
	{ 2, 95.162, 33.926 },
	{ 2, 95.326, 33.844 },
	{ 2, 95.543, 33.845 },
	{ 2, 95.597, 33.886 },
	{ 2, 95.815, 33.804 },
	{ 2, 96.086, 33.803 },
	{ 2, 96.248, 33.680 },
	{ 2, 96.411, 33.679 },
	{ 2, 96.629, 33.759 },
	{ 2, 96.630, 33.841 },
	{ 2, 96.792, 33.758 },
	{ 2, 96.903, 33.920 },
	{ 2, 97.118, 33.795 },
	{ 2, 97.172, 33.795 },
	{ 2, 97.335, 33.792 },
	{ 2, 97.499, 33.831 },
	{ 2, 97.610, 33.911 },
	{ 2, 97.988, 33.823 },
	{ 2, 97.992, 33.945 },
	{ 2, 98.104, 34.066 },
	{ 2, 98.268, 34.062 },
	{ 2, 98.378, 34.101 },
	{ 2, 98.430, 34.018 },
	{ 2, 98.596, 34.096 },
	{ 2, 98.758, 34.051 },
	{ 2, 98.979, 34.127 },
	{ 2, 99.199, 34.161 },
	{ 2, 99.261, 34.323 },
	{ 2, 99.372, 34.361 },
	{ 2, 99.753, 34.307 },
	{ 2,100.037, 34.502 },
	{ 2,100.017, 35.117 },
	{ 2,100.033, 36.385 },
	{ 2,100.540, 36.407 },
	{ 2,103.016, 36.407 },
	{ 3,103.016, 36.407 },
	{ 2,103.008, 36.899 },
	{ 3,103.008, 36.899 },
	{ 2,102.496, 36.888 },
	{ 2,102.045, 36.912 },
	{ 3, 94.039, 32.974 },
	{ 2, 94.082, 33.507 },
	{ 2, 94.190, 33.549 },
	{ 2, 94.406, 33.552 },
	{ 2, 94.514, 33.594 },
	{ 3, 93.845, 29.731 },
	{ 2, 93.896, 29.772 },
	{ 2, 93.895, 29.814 },
	{ 2, 93.842, 29.854 },
	{ 2, 93.682, 30.057 },
	{ 2, 93.677, 30.262 },
	{ 2, 93.721, 30.592 },
	{ 2, 93.558, 30.835 },
	{ 2, 93.556, 30.917 },
	{ 2, 93.553, 31.040 },
	{ 2, 93.601, 31.205 },
	{ 2, 93.705, 31.289 },
	{ 2, 93.753, 31.454 },
	{ 2, 93.856, 31.579 },
	{ 2, 93.801, 31.660 },
	{ 2, 93.851, 31.784 },
	{ 2, 94.059, 31.992 },
	{ 2, 94.039, 32.974 },
	{ 3, 93.845, 29.731 },
	{ 2, 93.534, 29.766 },
	{ 2, 93.171, 29.800 },
	{ 2, 92.967, 29.713 },
	{ 2, 92.662, 29.582 },
	{ 2, 92.354, 29.532 },
	{ 2, 92.042, 29.605 },
	{ 2, 92.143, 29.649 },
	{ 2, 92.191, 29.733 },
	{ 2, 92.088, 29.730 },
	{ 2, 91.929, 29.807 },
	{ 2, 91.824, 29.844 },
	{ 2, 91.879, 29.764 },
	{ 2, 91.881, 29.723 },
	{ 2, 91.776, 29.760 },
	{ 2, 91.621, 29.755 },
	{ 2, 91.627, 29.632 },
	{ 2, 91.528, 29.546 },
	{ 2, 91.425, 29.542 },
	{ 2, 91.273, 29.495 },
	{ 2, 91.177, 29.367 },
	{ 2, 91.083, 29.199 },
	{ 2, 90.880, 29.149 },
	{ 2, 90.780, 29.104 },
	{ 2, 90.673, 29.181 },
	{ 2, 90.565, 29.259 },
	{ 2, 90.512, 29.298 },
	{ 2, 90.414, 29.211 },
	{ 2, 90.358, 29.290 },
	{ 2, 90.217, 29.077 },
	{ 2, 90.001, 29.232 },
	{ 2, 89.993, 29.355 },
	{ 2, 90.036, 29.481 },
	{ 2, 89.830, 29.470 },
	{ 2, 89.788, 29.344 },
	{ 2, 89.688, 29.298 },
	{ 2, 89.537, 29.248 },
	{ 2, 89.441, 29.161 },
	{ 2, 89.345, 29.073 },
	{ 2, 89.351, 28.991 },
	{ 2, 89.143, 29.020 },
	{ 2, 89.137, 29.102 },
	{ 2, 89.031, 29.137 },
	{ 2, 89.028, 29.178 },
	{ 2, 89.025, 29.219 },
	{ 2, 89.127, 29.225 },
	{ 2, 89.226, 29.272 },
	{ 2, 89.323, 29.360 },
	{ 2, 89.525, 29.413 },
	{ 2, 89.567, 29.539 },
	{ 2, 89.507, 29.659 },
	{ 2, 89.449, 29.738 },
	{ 2, 89.285, 29.853 },
	{ 2, 89.176, 29.929 },
	{ 2, 89.166, 30.052 },
	{ 2, 89.156, 30.175 },
	{ 2, 89.425, 30.067 },
	{ 2, 89.586, 29.993 },
	{ 2, 89.595, 29.870 },
	{ 2, 89.695, 29.916 },
	{ 2, 89.845, 30.007 },
	{ 2, 89.686, 30.039 },
	{ 2, 89.626, 30.160 },
	{ 2, 89.732, 30.124 },
	{ 2, 89.784, 30.127 },
	{ 2, 89.885, 30.173 },
	{ 2, 89.997, 30.055 },
	{ 2, 90.256, 30.068 },
	{ 2, 90.406, 30.158 },
	{ 2, 90.346, 30.278 },
	{ 2, 90.182, 30.394 },
	{ 2, 90.032, 30.304 },
	{ 2, 89.879, 30.255 },
	{ 2, 89.623, 30.201 },
	{ 2, 89.522, 30.154 },
	{ 3,106.574, 31.696 },
	{ 2,106.411, 31.670 },
	{ 2,106.158, 31.364 },
	{ 2,105.928, 31.219 },
	{ 2,105.579, 30.961 },
	{ 2,105.181, 30.706 },
	{ 2,104.949, 30.519 },
	{ 2,104.757, 30.205 },
	{ 2,104.661, 29.799 },
	{ 2,104.425, 29.529 },
	{ 2,104.199, 29.340 },
	{ 2,103.773, 29.206 },
	{ 2,103.659, 29.091 },
	{ 2,103.392, 28.985 },
	{ 2,103.184, 28.958 },
	{ 2,102.899, 29.225 },
	{ 2,102.814, 29.437 },
	{ 2,102.725, 29.607 },
	{ 2,102.526, 29.702 },
	{ 2,102.378, 29.793 },
	{ 2,101.960, 29.735 },
	{ 2,101.596, 29.713 },
	{ 2,101.441, 29.721 },
	{ 2,101.330, 29.604 },
	{ 2,101.273, 29.524 },
	{ 2,101.221, 29.527 },
	{ 2,101.059, 29.411 },
	{ 2,100.841, 29.215 },
	{ 2,100.677, 29.057 },
	{ 2,100.611, 28.813 },
	{ 2,100.447, 28.614 },
	{ 2,100.331, 28.371 },
	{ 2,100.221, 28.210 },
	{ 2, 99.898, 27.851 },
	{ 2, 99.739, 27.692 },
	{ 2, 99.530, 27.534 },
	{ 2, 99.521, 27.328 },
	{ 2, 99.403, 26.918 },
	{ 2, 99.249, 26.840 },
	{ 2, 99.191, 26.635 },
	{ 2, 99.082, 26.390 },
	{ 2, 98.832, 26.356 },
	{ 2, 98.731, 26.317 },
	{ 2, 98.679, 26.236 },
	{ 2, 98.430, 26.201 },
	{ 2, 98.279, 26.122 },
	{ 2, 98.128, 26.042 },
	{ 2, 97.979, 26.046 },
	{ 2, 97.782, 26.050 },
	{ 2, 97.482, 25.931 },
	{ 2, 97.383, 25.932 },
	{ 2, 97.334, 25.933 },
	{ 2, 97.137, 25.978 },
	{ 2, 97.187, 26.018 },
	{ 2, 97.189, 26.101 },
	{ 2, 97.288, 26.141 },
	{ 2, 97.340, 26.265 },
	{ 2, 97.444, 26.471 },
	{ 2, 97.445, 26.553 },
	{ 2, 97.500, 26.801 },
	{ 2, 97.551, 26.842 },
	{ 2, 97.554, 26.966 },
	{ 2, 97.455, 27.050 },
	{ 2, 97.456, 27.092 },
	{ 2, 97.457, 27.133 },
	{ 2, 97.460, 27.257 },
	{ 2, 97.510, 27.256 },
	{ 2, 97.659, 27.212 },
	{ 2, 97.711, 27.294 },
	{ 2, 97.816, 27.457 },
	{ 2, 97.766, 27.458 },
	{ 2, 97.611, 27.296 },
	{ 2, 97.562, 27.338 },
	{ 2, 97.513, 27.380 },
	{ 2, 97.513, 27.421 },
	{ 2, 97.513, 27.421 },
	{ 2, 97.511, 27.297 },
	{ 2, 97.510, 27.256 },
	{ 2, 97.461, 27.298 },
	{ 2, 97.412, 27.382 },
	{ 2, 97.267, 27.673 },
	{ 2, 97.317, 27.673 },
	{ 2, 97.367, 27.630 },
	{ 2, 97.368, 27.672 },
	{ 2, 97.420, 27.795 },
	{ 2, 97.522, 27.834 },
	{ 2, 97.523, 27.876 },
	{ 2, 97.372, 27.878 },
	{ 2, 97.271, 27.880 },
	{ 2, 97.219, 27.798 },
	{ 2, 97.119, 27.882 },
	{ 2, 97.274, 28.086 },
	{ 2, 97.173, 28.087 },
	{ 2, 97.225, 28.169 },
	{ 2, 97.123, 28.129 },
	{ 2, 96.971, 28.131 },
	{ 2, 96.972, 28.214 },
	{ 2, 96.922, 28.214 },
	{ 2, 96.920, 28.132 },
	{ 2, 96.820, 28.216 },
	{ 2, 96.770, 28.299 },
	{ 2, 96.823, 28.422 },
	{ 2, 96.823, 28.463 },
	{ 2, 96.773, 28.463 },
	{ 2, 96.721, 28.381 },
	{ 2, 96.720, 28.340 },
	{ 2, 96.619, 28.341 },
	{ 2, 96.517, 28.383 },
	{ 2, 96.416, 28.425 },
	{ 2, 96.468, 28.507 },
	{ 2, 96.518, 28.466 },
	{ 2, 96.519, 28.548 },
	{ 2, 96.621, 28.547 },
	{ 2, 96.622, 28.630 },
	{ 2, 96.571, 28.671 },
	{ 2, 96.468, 28.590 },
	{ 2, 96.418, 28.673 },
	{ 2, 96.367, 28.673 },
	{ 2, 96.316, 28.673 },
	{ 2, 96.215, 28.756 },
	{ 2, 96.214, 28.715 },
	{ 2, 96.214, 28.632 },
	{ 2, 96.163, 28.633 },
	{ 2, 96.112, 28.592 },
	{ 2, 95.806, 28.757 },
	{ 2, 95.755, 28.757 },
	{ 2, 95.755, 28.757 },
	{ 2, 96.061, 28.592 },
	{ 2, 96.366, 28.467 },
	{ 2, 96.365, 28.426 },
	{ 2, 95.857, 28.634 },
	{ 2, 95.295, 28.963 },
	{ 2, 95.243, 29.127 },
	{ 2, 95.140, 29.209 },
	{ 2, 94.934, 29.290 },
	{ 2, 94.881, 29.413 },
	{ 2, 94.932, 29.455 },
	{ 2, 94.983, 29.538 },
	{ 2, 94.982, 29.702 },
	{ 2, 94.982, 29.702 },
	{ 2, 94.722, 29.782 },
	{ 2, 94.722, 29.824 },
	{ 2, 94.671, 29.782 },
	{ 2, 94.776, 29.577 },
	{ 2, 94.776, 29.577 },
	{ 2, 94.725, 29.536 },
	{ 2, 94.622, 29.576 },
	{ 2, 94.519, 29.575 },
	{ 2, 94.519, 29.534 },
	{ 2, 94.622, 29.535 },
	{ 2, 94.778, 29.413 },
	{ 2, 94.779, 29.372 },
	{ 2, 94.052, 29.693 },
	{ 2, 93.845, 29.731 },
	{ 3,106.574, 31.696 },
	{ 2,106.643, 31.814 },
	{ 2,106.659, 31.936 },
	{ 2,103.088, 31.931 },
	{ 2,103.072, 36.404 },
	{ 2,103.016, 36.407 },
	{ 3,109.062, 31.268 },
	{ 2,109.034, 36.889 },
	{ 3,109.062, 31.268 },
	{ 2,108.267, 31.276 },
	{ 2,108.232, 31.734 },
	{ 2,106.574, 31.696 },
	{ 3,109.034, 36.889 },
	{ 2,108.292, 36.885 },
	{ 2,106.926, 36.893 },
	{ 2,105.391, 36.900 },
	{ 2,104.026, 36.876 },
	{ 2,103.008, 36.899 },
	{ 3,109.034, 36.889 },
	{ 2,109.061, 40.897 },
	{ 3,109.061, 40.897 },
	{ 2,109.061, 40.897 },
	{ 3,107.922, 40.926 },
	{ 2,106.236, 40.909 },
	{ 2,104.076, 40.901 },
	{ 3,114.731, 32.675 },
	{ 2,114.731, 32.675 },
	{ 2,114.574, 32.700 },
	{ 2,114.497, 32.838 },
	{ 2,114.526, 32.958 },
	{ 2,114.704, 33.013 },
	{ 2,114.690, 33.182 },
	{ 2,114.752, 33.214 },
	{ 2,114.729, 33.343 },
	{ 2,114.632, 33.400 },
	{ 2,114.555, 33.538 },
	{ 2,114.575, 33.618 },
	{ 2,114.570, 33.827 },
	{ 2,114.483, 33.924 },
	{ 2,114.210, 34.176 },
	{ 2,114.166, 34.224 },
	{ 2,114.376, 34.400 },
	{ 2,114.405, 34.520 },
	{ 2,114.581, 34.784 },
	{ 2,114.675, 34.936 },
	{ 3,114.731, 32.675 },
	{ 2,114.798, 32.497 },
	{ 2,114.840, 32.448 },
	{ 2,114.312, 32.284 },
	{ 2,113.497, 32.037 },
	{ 2,112.055, 31.585 },
	{ 2,111.143, 31.297 },
	{ 2,110.660, 31.278 },
	{ 2,109.062, 31.268 },
	{ 3,114.675, 34.936 },
	{ 2,114.626, 35.194 },
	{ 2,114.706, 35.514 },
	{ 2,114.742, 35.884 },
	{ 2,114.772, 36.004 },
	{ 2,114.553, 36.038 },
	{ 2,114.388, 36.064 },
	{ 2,114.239, 35.920 },
	{ 2,114.129, 35.937 },
	{ 2,114.059, 36.114 },
	{ 2,114.080, 36.902 },
	{ 3,114.675, 34.936 },
	{ 2,118.448, 37.761 },
	{ 2,120.003, 38.899 },
	{ 2,119.994, 41.909 },
	{ 3,114.080, 36.902 },
	{ 2,114.030, 41.875 },
	{ 3,114.080, 36.902 },
	{ 2,112.753, 36.885 },
	{ 2,111.436, 36.895 },
	{ 2,110.694, 36.905 },
	{ 2,109.720, 36.896 },
	{ 2,109.034, 36.889 },
	{ 3,114.030, 41.875 },
	{ 2,112.184, 41.870 },
	{ 2,111.082, 41.879 },
	{ 3,111.082, 41.879 },
	{ 2,111.049, 40.884 },
	{ 2,109.061, 40.897 },
	{ 3,116.999, 41.885 },
	{ 2,114.030, 41.875 },
	{ 3,119.994, 41.909 },
	{ 2,119.307, 41.908 },
	{ 2,116.999, 41.885 },
	{ 3,124.144, 41.914 },
	{ 2,124.227, 41.809 },
	{ 2,124.130, 41.573 },
	{ 2,124.066, 41.416 },
	{ 2,124.068, 41.115 },
	{ 2,124.126, 41.102 },
	{ 2,124.062, 40.944 },
	{ 2,124.342, 40.410 },
	{ 2,124.302, 40.161 },
	{ 2,124.054, 40.003 },
	{ 2,123.919, 39.820 },
	{ 2,123.754, 39.558 },
	{ 2,123.783, 39.166 },
	{ 2,123.650, 38.983 },
	{ 2,123.716, 38.840 },
	{ 2,123.457, 38.642 },
	{ 2,123.201, 38.444 },
	{ 2,123.001, 38.232 },
	{ 2,122.942, 38.075 },
	{ 2,122.967, 37.984 },
	{ 2,122.993, 37.893 },
	{ 2,122.897, 37.957 },
	{ 2,122.743, 37.864 },
	{ 2,122.604, 37.809 },
	{ 2,122.465, 37.755 },
	{ 2,122.410, 37.767 },
	{ 2,122.453, 37.885 },
	{ 2,122.482, 37.964 },
	{ 2,122.456, 38.054 },
	{ 2,122.346, 38.078 },
	{ 2,122.192, 37.984 },
	{ 2,122.247, 37.972 },
	{ 2,122.384, 37.857 },
	{ 2,122.300, 37.791 },
	{ 2,122.271, 37.712 },
	{ 2,122.173, 37.606 },
	{ 2,122.076, 37.499 },
	{ 2,121.978, 37.393 },
	{ 2,122.088, 37.369 },
	{ 2,122.240, 37.464 },
	{ 2,122.338, 37.570 },
	{ 2,122.326, 37.700 },
	{ 2,122.451, 37.715 },
	{ 2,122.448, 37.546 },
	{ 2,122.460, 37.416 },
	{ 2,122.388, 37.219 },
	{ 2,122.317, 37.022 },
	{ 2,122.028, 36.873 },
	{ 2,121.905, 36.857 },
	{ 2,121.781, 36.672 },
	{ 2,121.902, 36.519 },
	{ 2,121.915, 36.389 },
	{ 2,121.873, 36.270 },
	{ 2,121.778, 36.164 },
	{ 2,121.534, 35.963 },
	{ 2,121.345, 35.749 },
	{ 2,121.170, 35.575 },
	{ 2,120.996, 35.400 },
	{ 2,120.876, 35.383 },
	{ 2,120.836, 35.265 },
	{ 2,120.851, 35.135 },
	{ 2,120.718, 35.078 },
	{ 2,120.611, 35.101 },
	{ 2,120.612, 34.932 },
	{ 2,120.601, 34.723 },
	{ 2,120.655, 34.542 },
	{ 2,120.576, 34.474 },
	{ 2,120.432, 34.378 },
	{ 2,120.154, 34.394 },
	{ 2,119.799, 34.340 },
	{ 2,119.456, 34.326 },
	{ 2,119.248, 34.199 },
	{ 2,119.158, 34.091 },
	{ 2,118.951, 33.963 },
	{ 2,118.493, 33.927 },
	{ 2,118.434, 33.728 },
	{ 2,118.253, 33.679 },
	{ 2,118.094, 33.710 },
	{ 2,117.879, 33.541 },
	{ 2,117.664, 33.371 },
	{ 2,117.450, 33.202 },
	{ 2,117.235, 32.822 },
	{ 2,117.202, 32.702 },
	{ 2,117.244, 32.653 },
	{ 2,117.192, 32.662 },
	{ 2,117.107, 32.552 },
	{ 2,117.159, 32.542 },
	{ 2,117.137, 32.463 },
	{ 2,114.731, 32.675 },
	{ 3,124.144, 41.914 },
	{ 2,123.822, 41.899 },
	{ 2,119.994, 41.909 },
	{ 3,116.902, 45.887 },
	{ 2,116.775, 45.694 },
	{ 2,116.575, 45.682 },
	{ 2,116.463, 45.529 },
	{ 2,116.844, 44.874 },
	{ 2,116.916, 44.692 },
	{ 2,117.027, 44.632 },
	{ 2,117.195, 44.350 },
	{ 2,117.131, 44.148 },
	{ 2,116.997, 44.127 },
	{ 2,116.898, 44.016 },
	{ 2,117.053, 43.694 },
	{ 2,116.999, 41.885 },
	{ 3,123.424, 46.130 },
	{ 2,123.609, 46.092 },
	{ 2,123.749, 46.106 },
	{ 2,123.889, 46.120 },
	{ 2,123.838, 46.000 },
	{ 2,123.910, 45.855 },
	{ 2,123.886, 45.642 },
	{ 2,123.846, 45.390 },
	{ 2,123.924, 45.417 },
	{ 2,123.910, 45.072 },
	{ 2,123.957, 44.716 },
	{ 2,124.021, 44.399 },
	{ 2,124.067, 44.043 },
	{ 2,124.139, 43.595 },
	{ 2,124.318, 43.254 },
	{ 2,124.463, 42.833 },
	{ 2,124.488, 42.741 },
	{ 2,124.347, 42.557 },
	{ 2,124.407, 42.242 },
	{ 2,124.234, 41.980 },
	{ 2,124.144, 41.914 },
	{ 3,123.424, 46.130 },
	{ 2,123.329, 46.063 },
	{ 2,123.065, 46.073 },
	{ 2,122.892, 45.978 },
	{ 2,122.765, 45.830 },
	{ 2,122.729, 45.577 },
	{ 2,122.696, 45.497 },
	{ 2,122.280, 45.450 },
	{ 2,121.912, 45.523 },
	{ 2,121.805, 45.587 },
	{ 2,121.543, 45.594 },
	{ 2,121.266, 45.561 },
	{ 2,121.173, 45.493 },
	{ 2,121.066, 45.556 },
	{ 2,120.865, 45.551 },
	{ 2,120.572, 45.648 },
	{ 2,120.419, 45.590 },
	{ 2,120.171, 45.635 },
	{ 2,120.124, 45.687 },
	{ 2,119.877, 45.732 },
	{ 2,119.691, 45.765 },
	{ 2,119.581, 45.827 },
	{ 2,119.180, 45.812 },
	{ 2,118.945, 45.895 },
	{ 2,116.902, 45.887 },
	{ 3,116.995, 48.886 },
	{ 2,120.797, 48.907 },
	{ 2,122.674, 48.906 },
	{ 2,122.738, 48.893 },
	{ 2,122.653, 48.690 },
	{ 2,122.555, 48.621 },
	{ 2,122.427, 48.646 },
	{ 2,122.410, 48.605 },
	{ 2,122.376, 48.524 },
	{ 2,122.407, 48.430 },
	{ 2,122.373, 48.349 },
	{ 2,122.535, 48.405 },
	{ 2,122.599, 48.393 },
	{ 2,122.565, 48.312 },
	{ 2,122.501, 48.324 },
	{ 2,122.484, 48.283 },
	{ 2,122.307, 48.186 },
	{ 2,122.304, 48.012 },
	{ 2,122.191, 47.902 },
	{ 2,122.268, 47.756 },
	{ 2,122.359, 47.476 },
	{ 2,122.260, 47.234 },
	{ 2,122.449, 47.197 },
	{ 2,122.541, 47.092 },
	{ 2,122.634, 46.986 },
	{ 2,122.792, 47.042 },
	{ 2,122.855, 47.029 },
	{ 2,122.934, 47.057 },
	{ 2,122.968, 47.138 },
	{ 2,122.733, 47.228 },
	{ 2,122.746, 47.095 },
	{ 2,122.667, 47.067 },
	{ 2,122.591, 47.213 },
	{ 2,122.528, 47.225 },
	{ 2,122.468, 47.411 },
	{ 2,122.628, 47.467 },
	{ 2,122.502, 47.492 },
	{ 2,122.551, 47.614 },
	{ 2,122.395, 47.732 },
	{ 2,122.428, 47.813 },
	{ 2,122.508, 47.841 },
	{ 2,122.522, 47.707 },
	{ 2,122.631, 47.642 },
	{ 2,122.678, 47.589 },
	{ 2,122.851, 47.511 },
	{ 2,123.035, 47.299 },
	{ 2,123.035, 47.299 },
	{ 2,122.846, 47.337 },
	{ 2,122.783, 47.349 },
	{ 2,122.955, 47.271 },
	{ 2,123.081, 47.246 },
	{ 2,123.069, 47.380 },
	{ 2,122.931, 47.539 },
	{ 2,122.745, 47.750 },
	{ 2,122.618, 47.775 },
	{ 2,122.605, 47.909 },
	{ 2,122.639, 47.990 },
	{ 2,122.719, 48.018 },
	{ 2,122.812, 47.912 },
	{ 2,122.956, 47.928 },
	{ 2,122.990, 48.009 },
	{ 2,123.088, 48.077 },
	{ 2,123.279, 48.039 },
	{ 2,123.584, 48.109 },
	{ 2,123.711, 48.083 },
	{ 2,124.000, 48.111 },
	{ 2,124.570, 48.301 },
	{ 2,124.633, 48.288 },
	{ 2,124.670, 48.060 },
	{ 2,124.634, 47.979 },
	{ 2,124.598, 47.899 },
	{ 2,124.562, 47.818 },
	{ 2,124.400, 47.764 },
	{ 2,124.364, 47.684 },
	{ 2,124.258, 47.442 },
	{ 2,124.233, 47.228 },
	{ 2,124.100, 47.081 },
	{ 2,124.093, 46.907 },
	{ 2,124.013, 46.880 },
	{ 2,124.048, 46.960 },
	{ 2,123.986, 46.973 },
	{ 2,123.889, 46.906 },
	{ 2,123.826, 46.919 },
	{ 2,123.747, 46.892 },
	{ 2,123.854, 46.826 },
	{ 2,123.916, 46.813 },
	{ 2,123.961, 46.760 },
	{ 2,123.979, 46.800 },
	{ 2,124.058, 46.827 },
	{ 2,124.051, 46.654 },
	{ 2,123.972, 46.627 },
	{ 2,123.847, 46.652 },
	{ 2,123.768, 46.625 },
	{ 2,123.858, 46.519 },
	{ 2,123.824, 46.439 },
	{ 2,123.851, 46.346 },
	{ 2,123.896, 46.293 },
	{ 2,123.958, 46.280 },
	{ 2,123.937, 46.546 },
	{ 2,123.999, 46.533 },
	{ 2,123.999, 46.533 },
	{ 2,123.992, 46.360 },
	{ 2,124.002, 46.227 },
	{ 2,123.985, 46.187 },
	{ 2,123.941, 46.240 },
	{ 2,123.845, 46.173 },
	{ 2,123.721, 46.199 },
	{ 2,123.660, 46.212 },
	{ 2,123.362, 46.143 },
	{ 2,123.345, 46.103 },
	{ 2,123.345, 46.103 },
	{ 2,123.424, 46.130 },
	{ 3,116.995, 48.886 },
	{ 2,117.019, 46.254 },
	{ 2,116.891, 46.060 },
	{ 2,116.902, 45.887 },
	{ 3,122.689, 48.112 },
	{ 2,122.592, 48.043 },
	{ 2,122.528, 48.056 },
	{ 2,122.445, 47.853 },
	{ 2,122.301, 47.837 },
	{ 2,122.334, 47.918 },
	{ 2,122.431, 47.987 },
	{ 2,122.545, 48.096 },
	{ 2,122.625, 48.124 },
	{ 2,122.451, 48.202 },
	{ 2,122.468, 48.243 },
	{ 2,122.565, 48.312 },
	{ 2,122.689, 48.112 },
	{ 3,122.825, 48.436 },
	{ 2,122.761, 48.449 },
	{ 2,122.774, 48.315 },
	{ 2,122.889, 48.424 },
	{ 2,122.825, 48.436 },
	{ 3,123.068, 48.520 },
	{ 2,123.004, 48.533 },
	{ 2,122.987, 48.492 },
	{ 2,122.889, 48.424 },
	{ 2,122.935, 48.371 },
	{ 2,123.034, 48.439 },
	{ 2,123.051, 48.480 },
	{ 2,123.068, 48.520 },
	{ 3,122.846, 48.652 },
	{ 2,122.683, 48.596 },
	{ 2,122.731, 48.543 },
	{ 2,122.829, 48.611 },
	{ 2,122.778, 48.490 },
	{ 2,122.940, 48.546 },
	{ 2,122.846, 48.652 },
	{ 3,116.038, 48.898 },
	{ 2,116.995, 48.886 },
	{ 3,116.038, 48.898 },
	{ 2,116.068, 47.900 },
	{ 2,115.709, 47.609 },
	{ 2,115.763, 47.343 },
	{ 2,115.293, 47.111 },
	{ 2,115.093, 46.883 },
	{ 2,114.807, 46.581 },
	{ 2,114.691, 46.640 },
	{ 2,114.593, 46.525 },
	{ 2,114.339, 46.560 },
	{ 2,114.328, 46.519 },
	{ 2,114.420, 46.379 },
	{ 2,114.397, 46.297 },
	{ 2,114.529, 46.066 },
	{ 2,114.375, 45.747 },
	{ 2,114.563, 45.721 },
	{ 2,114.517, 45.558 },
	{ 2,114.569, 45.508 },
	{ 2,114.472, 45.394 },
	{ 2,114.273, 45.379 },
	{ 2,114.005, 45.585 },
	{ 2,113.943, 45.594 },
	{ 2,113.836, 45.438 },
	{ 2,113.592, 45.005 },
	{ 2,113.446, 44.940 },
	{ 2,113.476, 44.809 },
	{ 2,113.393, 44.736 },
	{ 2,113.258, 44.711 },
	{ 2,113.082, 44.523 },
	{ 2,113.041, 44.360 },
	{ 2,112.887, 44.254 },
	{ 2,112.732, 44.400 },
	{ 2,112.403, 44.357 },
	{ 2,112.238, 44.461 },
	{ 2,111.466, 44.428 },
	{ 2,111.513, 44.632 },
	{ 2,111.389, 44.647 },
	{ 2,111.076, 44.389 },
	{ 3,111.076, 44.389 },
	{ 2,111.082, 41.879 },
	{ 3,109.061, 40.897 },
	{ 2,107.922, 40.926 },
};

int nPoints = sizeof(usMap) / sizeof(usMap[0]);

cvMultiPoint* ReadMapBounds( int& nMultiPoints )
{
	cvMultiPoint* multiPoints;

	int iPoint;
	const int MaxLineLength = 200;
	char line[ 200 ];

	const int numpoints = 2800;

	multiPoints = (cvMultiPoint*) malloc( numpoints * sizeof(cvMultiPoint) );

	for (iPoint=0; iPoint < nPoints; iPoint++) {

		multiPoints[iPoint].pen = usMap[iPoint].pen;
		multiPoints[iPoint].x   = usMap[iPoint].lon;
		multiPoints[iPoint].y   = usMap[iPoint].lat;
	}

	nMultiPoints = iPoint;

	return multiPoints;
}

